@@ -30,12 +30,14 @@ parameters::parameters(int argc, char *argv[])
 	diff_site_discordance = false;
 	diff_switch_error = false;
 	end_pos = numeric_limits<int>::max();
+	exclude_positions_file = "";
 	force_write_index = false;
-	fst_file = "";
-	fst_file_compressed = false;
+	hapmap_fst_file = "";
+	hapmap_fst_file_compressed = false;
 	indv_exclude_file = "";
 	indv_keep_file = "";
 	invert_mask = false;
+	keep_only_indels = false;
 	recode_all_INFO = false;
 	ld_bp_window_size = numeric_limits<int>::max();
 	ld_snp_window_size = numeric_limits<int>::max();
@@ -105,8 +107,10 @@ parameters::parameters(int argc, char *argv[])
 	plink_tped_output = false;
 	positions_file = "";
 	recode = false;
+	recode_to_stream = false;
 	remove_all_filtered_genotypes = false;
 	remove_all_filtered_sites = false;
+	remove_indels = false;
 	snps_to_exclude_file = "";
 	snps_to_keep_file = "";
 	start_pos = -1;
@@ -137,6 +141,7 @@ void parameters::read_parameters()
 		else if (in_str == "--diff") { diff_file = get_arg(i+1); diff_file_compressed = false; i++; }	// Calculate some concensus statistics
 		else if (in_str == "--exclude-bed") { BED_file = get_arg(i+1); i++; BED_exclude=true; }
 		else if (in_str == "--exclude") { snps_to_exclude_file = get_arg(i+1); i++; }				// List of SNPs to exclude
+		else if (in_str == "--exclude-positions") { exclude_positions_file = get_arg(i+1); i++; }
 		else if (in_str == "--extract-FORMAT-info") { FORMAT_id_to_extract = get_arg(i+1); i++; }
 		else if (in_str == "--FILTER-summary") {output_filter_summary = true;}
 		else if (in_str == "--filtered-sites") {output_filtered_sites = true;}
@@ -144,16 +149,16 @@ void parameters::read_parameters()
 		else if (in_str == "--freq") output_freq = true;									// Output per-site frequency statistics
 		else if (in_str == "--freq2") {output_freq = true;	suppress_allele_output = true; }							// Output per-site frequency statistics
 		else if (in_str == "--from-bp") { start_pos = atoi(get_arg(i+1).c_str()); i++; }					// Start position
-		else if (in_str == "--fst") { fst_file = get_arg(i+1); fst_file_compressed = false; i++; }
-		else if (in_str == "--fst-pop") {fst_populations.push_back(get_arg(i+1)); i++; }
 		else if (in_str == "--geno-depth") output_geno_depth = true;						// Output Depth for each genoptype
 		else if (in_str == "--geno-r2") { output_geno_rsq = true; min_alleles = 2; max_alleles = 2; } // Output pairwise LD (r^2)
 		else if (in_str == "--geno") { min_site_call_rate = atof(get_arg(i+1).c_str()); i++; }				// Minimum per-site call rate
 		else if (in_str == "--get-INFO") { INFO_to_extract.push_back(get_arg(i+1)); i++; }	// Add to list of INFO fields to extract
 		else if (in_str == "--gzdiff") { diff_file = get_arg(i+1); diff_file_compressed = true; i++; }	// Calculate some concensus statistics
-		else if (in_str == "--gzfst") { fst_file = get_arg(i+1); fst_file_compressed = true; i++; }
 		else if (in_str == "--gzvcf") { vcf_filename = get_arg(i+1); vcf_compressed = true; i++; } 				// VCF file to process
 		else if (in_str == "--hap-r2") { output_hap_rsq = true; phased_only = true; min_alleles = 2; max_alleles = 2; }	// Output pairwise LD (r^2)
+		else if (in_str == "--hapmap-fst-file") { hapmap_fst_file = get_arg(i+1); hapmap_fst_file_compressed = false; i++; }
+		else if (in_str == "--hapmap-fst-pop") { hapmap_fst_populations.push_back(get_arg(i+1)); i++; }
+		else if (in_str == "--hapmap-fst-gzfile") { hapmap_fst_file = get_arg(i+1); hapmap_fst_file_compressed = true; i++; }
 		else if (in_str == "--hardy") output_HWE = true;									// Output HWE statistics
 		else if (in_str == "--het") output_het = true;									// Output heterozygosity statistics
 		else if (in_str == "--hwe") { max_alleles = 2; min_HWE_pvalue = atof(get_arg(i+1).c_str()); i++; }					// Minimum per-site HWE p-value
@@ -163,6 +168,7 @@ void parameters::read_parameters()
 		else if (in_str == "--invert-mask") { mask_file = get_arg(i+1); i++; invert_mask = true; }
 		else if (in_str == "--keep-filtered") { site_filter_flags_to_keep.insert(get_arg(i+1)); i++; }	// Remove a specific filter flag
 		else if (in_str == "--keep") { indv_keep_file = get_arg(i+1); i++; }						// List of individuals to keep
+		else if (in_str == "--keep-only-indels") { keep_only_indels = true; }
 		else if (in_str == "--keep-INFO") { site_INFO_flags_to_keep.insert(get_arg(i+1)); i++; }	// Filter sites by INFO flags
 		else if (in_str == "--keep-INFO-all") { recode_all_INFO=true; }	// Old command (soon to be depreciated)
 		else if (in_str == "--ld-window-bp") { ld_bp_window_size = atoi(get_arg(i+1).c_str()); i++; }	// Max bp distance for LD output
@@ -205,6 +211,7 @@ void parameters::read_parameters()
 		else if (in_str == "--plink-tped") plink_tped_output = true;	// Output as PLINK tped file
 		else if (in_str == "--positions") { positions_file = get_arg(i+1); i++; }
 		else if (in_str == "--recode") recode = true;										// Output VCF file
+		else if (in_str == "--recode-to-stream") {  recode_to_stream = true; LOG.set_screen_output(false); }
 		else if (in_str == "--recode-INFO-all") { recode_all_INFO=true; }		// Specify INFO to keep when recoding
 		else if (in_str == "--recode-INFO") { recode_INFO_to_keep.insert(get_arg(i+1)); i++; }		// Specify INFO to keep when recoding
 		else if (in_str == "--relatedness") { output_relatedness = true; }	// Estimate relatedness between individuals
@@ -212,6 +219,7 @@ void parameters::read_parameters()
 		else if (in_str == "--remove-filtered-geno-all") remove_all_filtered_genotypes = true;			// Remove genotypes flagged as filtered
 		else if (in_str == "--remove-filtered-geno") { geno_filter_flags_to_exclude.insert(get_arg(i+1)); i++; }		// Remove genotypes flagged as filtered
 		else if (in_str == "--remove-filtered") { site_filter_flags_to_exclude.insert(get_arg(i+1)); i++; }	// Remove a specific filter flag
+		else if (in_str == "--remove-indels") { remove_indels = true; }
 		else if (in_str == "--remove-indv") { indv_to_exclude.insert(get_arg(i+1)); i++; }						// List of individuals to keep
 		else if (in_str == "--remove-INFO") { site_INFO_flags_to_remove.insert(get_arg(i+1)); i++; }	// Filter sites by INFO flags
 		else if (in_str == "--remove") { indv_exclude_file = get_arg(i+1); i++; }					// List of individuals to exclude
@@ -229,6 +237,7 @@ void parameters::read_parameters()
 		else if (in_str == "--TsTv") {output_TsTv_bin_size = atoi(get_arg(i+1).c_str()); i++;}						// Output Ts/Tv stats
 		else if (in_str == "--TsTv-by-count") {output_TsTv_by_count = true; }						// Output Ts/Tv stats
 		else if (in_str == "--TsTv-by-qual") {output_TsTv_by_qual = true; }
+		else if (in_str == "--weir-fst-pop") { weir_fst_populations.push_back(get_arg(i+1)); i++; }
 		else if (in_str == "--window-pi") { pi_window_size = atoi(get_arg(i+1).c_str()); i++; }
 		else
 			error("Unknown option: " + string(in_str), 0);
@@ -248,216 +257,225 @@ void parameters::print_params()
 {
 	parameters defaults(0, 0);
 
-	printLOG("Parameters as interpreted:\n");
+	LOG.printLOG("Parameters as interpreted:\n");
 	if (vcf_filename != defaults.vcf_filename)
 	{
 		if (vcf_compressed == false)
-			printLOG("\t--vcf " + vcf_filename + "\n");
+			LOG.printLOG("\t--vcf " + vcf_filename + "\n");
 		else
-			printLOG("\t--gzvcf " + vcf_filename + "\n");
+			LOG.printLOG("\t--gzvcf " + vcf_filename + "\n");
 	}
 
-	if (chr_to_exclude != defaults.chr_to_exclude) printLOG("\t--not-chr " + chr_to_exclude + "\n");
-	if (chr_to_keep != defaults.chr_to_keep) printLOG("\t--chr " + chr_to_keep + "\n");
-	if (end_pos != defaults.end_pos) printLOG("\t--to-bp " + int2str(end_pos) + "\n");
-	if (force_write_index != defaults.force_write_index) printLOG("\t--force-index-write\n");
-	if (FORMAT_id_to_extract != defaults.FORMAT_id_to_extract) printLOG("\t--extract-FORMAT-info " + FORMAT_id_to_extract + "\n");
-	if (fst_file != defaults.fst_file)
+	if (chr_to_exclude != defaults.chr_to_exclude) LOG.printLOG("\t--not-chr " + chr_to_exclude + "\n");
+	if (chr_to_keep != defaults.chr_to_keep) LOG.printLOG("\t--chr " + chr_to_keep + "\n");
+	if (end_pos != defaults.end_pos) LOG.printLOG("\t--to-bp " + output_log::int2str(end_pos) + "\n");
+	if (exclude_positions_file != defaults.exclude_positions_file) LOG.printLOG("\t--exclude-positions " + exclude_positions_file + "\n");
+	if (force_write_index != defaults.force_write_index) LOG.printLOG("\t--force-index-write\n");
+	if (FORMAT_id_to_extract != defaults.FORMAT_id_to_extract) LOG.printLOG("\t--extract-FORMAT-info " + FORMAT_id_to_extract + "\n");
+	if (hapmap_fst_file != defaults.hapmap_fst_file)
 	{
-		if (vcf_compressed == false)
-			printLOG("\t--fst " + fst_file + "\n");
+		if (hapmap_fst_file_compressed == false)
+			LOG.printLOG("\t--hapmap-fst-file " + hapmap_fst_file + "\n");
 		else
 		{
-			printLOG("\t--gzfst " + fst_file + "\n");
+			LOG.printLOG("\t--hapmap-fst-gzfile " + hapmap_fst_file + "\n");
 		}
 	}
-	if (fst_populations.size() != 0)
+	if (hapmap_fst_populations.size() != 0)
 	{
-		for (unsigned int ui=0; ui<fst_populations.size(); ui++)
-			printLOG("\t--fst-pop " + fst_populations[ui] + "\n");
+		for (unsigned int ui=0; ui<hapmap_fst_populations.size(); ui++)
+			LOG.printLOG("\t--hapmap-fst-pop " + hapmap_fst_populations[ui] + "\n");
 	}
-	if (indv_exclude_file != defaults.indv_exclude_file) printLOG("\t--exclude " + indv_exclude_file + "\n");
-	if (indv_keep_file != defaults.indv_keep_file) printLOG("\t--keep " + indv_keep_file + "\n");
-	if (recode_all_INFO == true) printLOG("\t--recode-INFO-all\n");
-	if (ld_bp_window_size != defaults.ld_bp_window_size) printLOG("\t--ld-window-bp " + int2str(ld_bp_window_size) + "\n");
-	if (ld_snp_window_size != defaults.ld_snp_window_size) printLOG("\t--ld-window " + int2str(ld_snp_window_size) + "\n");
-	if (min_mac != defaults.min_mac) printLOG("\t--mac " + dbl2str(min_mac, 3) + "\n");
-	if (min_maf != defaults.min_maf) printLOG("\t--maf " + dbl2str(min_maf, 3) + "\n");
-	if (max_alleles != defaults.max_alleles) printLOG("\t--max-alleles " + int2str(max_alleles) + "\n");
-	if (max_genotype_depth != defaults.max_genotype_depth) printLOG("\t--maxDP " + dbl2str(max_genotype_depth, 3) + "\n");
-	if (max_indv_mean_depth != defaults.max_indv_mean_depth) printLOG("\t--max-indv-meanDP " + dbl2str(max_indv_mean_depth, 3) + "\n");
-	if (max_mac != defaults.max_mac) printLOG("\t--max-mac " + dbl2str(max_mac, 3) + "\n");
-	if (max_maf != defaults.max_maf) printLOG("\t--max-maf " + dbl2str(max_maf, 3) + "\n");
-	if (max_missing_call_count != defaults.max_missing_call_count) printLOG("\t--max-missing-count " + dbl2str(max_missing_call_count, 3) + "\n");
-	if (max_mean_depth != defaults.max_mean_depth) printLOG("\t--max-meanDP " + dbl2str(max_mean_depth, 3) + "\n");
-	if (max_non_ref_ac != defaults.max_non_ref_ac) printLOG("\t--max-non-ref-ac " + dbl2str(max_non_ref_ac, 3) + "\n");
-	if (max_non_ref_af != defaults.max_non_ref_af) printLOG("\t--max-non-ref-af " + dbl2str(max_non_ref_af, 3) + "\n");
-	if (max_N_indv != defaults.max_N_indv) printLOG("\t--max-indv " + int2str(max_N_indv) + "\n");
-	if (min_alleles != defaults.min_alleles) printLOG("\t--min-alleles " + int2str(min_alleles) + "\n");
-	if (min_genotype_depth != defaults.min_genotype_depth) printLOG("\t--minDP " + dbl2str(min_genotype_depth, 3) + "\n");
-	if (min_genotype_quality != defaults.min_genotype_quality) printLOG("\t--minGQ " + dbl2str(min_genotype_quality, 3) + "\n");
-	if (min_HWE_pvalue != defaults.min_HWE_pvalue) printLOG("\t--hwe " + dbl2str(min_HWE_pvalue, 3) + "\n");
-	if (min_indv_call_rate != defaults.min_indv_call_rate) printLOG("\t--mind " + dbl2str(min_indv_call_rate, 3) + "\n");
-	if (min_indv_mean_depth != defaults.min_indv_mean_depth) printLOG("\t--min-indv-meanDP " + dbl2str(min_indv_mean_depth, 3) + "\n");
-	if (min_interSNP_distance != defaults.min_interSNP_distance) printLOG("\t--thin " + int2str(min_interSNP_distance) + "\n");
-	if (min_kept_mask_value != defaults.min_kept_mask_value) printLOG("\t--mask-min " + int2str(min_kept_mask_value) + "\n");
-	if (min_mean_depth != defaults.min_mean_depth) printLOG("\t--min-meanDP " + dbl2str(min_mean_depth, 3) + "\n");
-	if (min_quality != defaults.min_quality) printLOG("\t--minQ " + dbl2str(min_quality, 3) + "\n");
-	if (min_r2 != defaults.min_r2) printLOG("\t--min-r2 " + dbl2str(min_r2, 3) + "\n");
-	if (min_site_call_rate != defaults.min_site_call_rate) printLOG("\t--geno " + dbl2str(min_site_call_rate, 3) + "\n");
-	if (min_non_ref_ac != defaults.min_non_ref_ac) printLOG("\t--non-ref-ac " + dbl2str(min_non_ref_ac, 3) + "\n");
-	if (min_non_ref_af != defaults.min_non_ref_af) printLOG("\t--non-ref-af " + dbl2str(min_non_ref_af, 3) + "\n");
-	if (output_012_matrix) printLOG("\t--012\n");
-	if (output_as_IMPUTE) printLOG("\t--IMPUTE\n");
-	if (output_BEAGLE_genotype_likelihoods) printLOG("\t--BEAGLE-GL\n");
-	if (output_counts && (suppress_allele_output==false)) printLOG("\t--counts\n");
-	if (output_counts && (suppress_allele_output==true)) printLOG("\t--counts2\n");
-	if (output_filter_summary) printLOG("\t--FILTER-summary\n");
-	if (output_filtered_sites != defaults.output_filtered_sites) printLOG("\t--filtered-sites\n");
-	if (output_freq && (suppress_allele_output==false)) printLOG("\t--freq\n");
-	if (output_freq && (suppress_allele_output==true)) printLOG("\t--freq2\n");
-	if (output_geno_depth) printLOG("\t--geno-depth\n");
-	if (output_geno_rsq) printLOG("\t--geno-r2\n");
-	if (output_hap_rsq) printLOG("\t--hap-r2\n");
-	if (output_het) printLOG("\t--het\n");
-	if (output_HWE) printLOG("\t--hardy\n");
-	if (output_indv_depth) printLOG("\t--depth\n");
-	if (output_interchromosomal_rsq) printLOG("\t--interchrom-geno-r2\n");
-	if (output_LROH != defaults.output_LROH) printLOG("\t--LROH\n");
-	if (output_missingness) printLOG("\t--missing\n");
+	if (weir_fst_populations.size() != 0)
+	{
+		for (unsigned int ui=0; ui<weir_fst_populations.size(); ui++)
+			LOG.printLOG("\t--weir-fst-pop " + weir_fst_populations[ui] + "\n");
+	}
+	if (indv_exclude_file != defaults.indv_exclude_file) LOG.printLOG("\t--exclude " + indv_exclude_file + "\n");
+	if (indv_keep_file != defaults.indv_keep_file) LOG.printLOG("\t--keep " + indv_keep_file + "\n");
+	if (recode_all_INFO == true) LOG.printLOG("\t--recode-INFO-all\n");
+	if (keep_only_indels != defaults.keep_only_indels) LOG.printLOG("\t--keep-only-indels\n");
+	if (ld_bp_window_size != defaults.ld_bp_window_size) LOG.printLOG("\t--ld-window-bp " + output_log::int2str(ld_bp_window_size) + "\n");
+	if (ld_snp_window_size != defaults.ld_snp_window_size) LOG.printLOG("\t--ld-window " + output_log::int2str(ld_snp_window_size) + "\n");
+	if (min_mac != defaults.min_mac) LOG.printLOG("\t--mac " + output_log::dbl2str(min_mac, 3) + "\n");
+	if (min_maf != defaults.min_maf) LOG.printLOG("\t--maf " + output_log::dbl2str(min_maf, 3) + "\n");
+	if (max_alleles != defaults.max_alleles) LOG.printLOG("\t--max-alleles " + output_log::int2str(max_alleles) + "\n");
+	if (max_genotype_depth != defaults.max_genotype_depth) LOG.printLOG("\t--maxDP " + output_log::dbl2str(max_genotype_depth, 3) + "\n");
+	if (max_indv_mean_depth != defaults.max_indv_mean_depth) LOG.printLOG("\t--max-indv-meanDP " + output_log::dbl2str(max_indv_mean_depth, 3) + "\n");
+	if (max_mac != defaults.max_mac) LOG.printLOG("\t--max-mac " + output_log::dbl2str(max_mac, 3) + "\n");
+	if (max_maf != defaults.max_maf) LOG.printLOG("\t--max-maf " + output_log::dbl2str(max_maf, 3) + "\n");
+	if (max_missing_call_count != defaults.max_missing_call_count) LOG.printLOG("\t--max-missing-count " + output_log::dbl2str(max_missing_call_count, 3) + "\n");
+	if (max_mean_depth != defaults.max_mean_depth) LOG.printLOG("\t--max-meanDP " + output_log::dbl2str(max_mean_depth, 3) + "\n");
+	if (max_non_ref_ac != defaults.max_non_ref_ac) LOG.printLOG("\t--max-non-ref-ac " + output_log::dbl2str(max_non_ref_ac, 3) + "\n");
+	if (max_non_ref_af != defaults.max_non_ref_af) LOG.printLOG("\t--max-non-ref-af " + output_log::dbl2str(max_non_ref_af, 3) + "\n");
+	if (max_N_indv != defaults.max_N_indv) LOG.printLOG("\t--max-indv " + output_log::int2str(max_N_indv) + "\n");
+	if (min_alleles != defaults.min_alleles) LOG.printLOG("\t--min-alleles " + output_log::int2str(min_alleles) + "\n");
+	if (min_genotype_depth != defaults.min_genotype_depth) LOG.printLOG("\t--minDP " + output_log::dbl2str(min_genotype_depth, 3) + "\n");
+	if (min_genotype_quality != defaults.min_genotype_quality) LOG.printLOG("\t--minGQ " + output_log::dbl2str(min_genotype_quality, 3) + "\n");
+	if (min_HWE_pvalue != defaults.min_HWE_pvalue) LOG.printLOG("\t--hwe " + output_log::dbl2str(min_HWE_pvalue, 3) + "\n");
+	if (min_indv_call_rate != defaults.min_indv_call_rate) LOG.printLOG("\t--mind " + output_log::dbl2str(min_indv_call_rate, 3) + "\n");
+	if (min_indv_mean_depth != defaults.min_indv_mean_depth) LOG.printLOG("\t--min-indv-meanDP " + output_log::dbl2str(min_indv_mean_depth, 3) + "\n");
+	if (min_interSNP_distance != defaults.min_interSNP_distance) LOG.printLOG("\t--thin " + output_log::int2str(min_interSNP_distance) + "\n");
+	if (min_kept_mask_value != defaults.min_kept_mask_value) LOG.printLOG("\t--mask-min " + output_log::int2str(min_kept_mask_value) + "\n");
+	if (min_mean_depth != defaults.min_mean_depth) LOG.printLOG("\t--min-meanDP " + output_log::dbl2str(min_mean_depth, 3) + "\n");
+	if (min_quality != defaults.min_quality) LOG.printLOG("\t--minQ " + output_log::dbl2str(min_quality, 3) + "\n");
+	if (min_r2 != defaults.min_r2) LOG.printLOG("\t--min-r2 " + output_log::dbl2str(min_r2, 3) + "\n");
+	if (min_site_call_rate != defaults.min_site_call_rate) LOG.printLOG("\t--geno " + output_log::dbl2str(min_site_call_rate, 3) + "\n");
+	if (min_non_ref_ac != defaults.min_non_ref_ac) LOG.printLOG("\t--non-ref-ac " + output_log::dbl2str(min_non_ref_ac, 3) + "\n");
+	if (min_non_ref_af != defaults.min_non_ref_af) LOG.printLOG("\t--non-ref-af " + output_log::dbl2str(min_non_ref_af, 3) + "\n");
+	if (output_012_matrix) LOG.printLOG("\t--012\n");
+	if (output_as_IMPUTE) LOG.printLOG("\t--IMPUTE\n");
+	if (output_BEAGLE_genotype_likelihoods) LOG.printLOG("\t--BEAGLE-GL\n");
+	if (output_counts && (suppress_allele_output==false)) LOG.printLOG("\t--counts\n");
+	if (output_counts && (suppress_allele_output==true)) LOG.printLOG("\t--counts2\n");
+	if (output_filter_summary) LOG.printLOG("\t--FILTER-summary\n");
+	if (output_filtered_sites != defaults.output_filtered_sites) LOG.printLOG("\t--filtered-sites\n");
+	if (output_freq && (suppress_allele_output==false)) LOG.printLOG("\t--freq\n");
+	if (output_freq && (suppress_allele_output==true)) LOG.printLOG("\t--freq2\n");
+	if (output_geno_depth) LOG.printLOG("\t--geno-depth\n");
+	if (output_geno_rsq) LOG.printLOG("\t--geno-r2\n");
+	if (output_hap_rsq) LOG.printLOG("\t--hap-r2\n");
+	if (output_het) LOG.printLOG("\t--het\n");
+	if (output_HWE) LOG.printLOG("\t--hardy\n");
+	if (output_indv_depth) LOG.printLOG("\t--depth\n");
+	if (output_interchromosomal_rsq) LOG.printLOG("\t--interchrom-geno-r2\n");
+	if (output_LROH != defaults.output_LROH) LOG.printLOG("\t--LROH\n");
+	if (output_missingness) LOG.printLOG("\t--missing\n");
 	if (output_PCA != defaults.output_PCA)
 	{
 		if (PCA_no_normalisation == false)
-			printLOG("\t--pca\n");
+			LOG.printLOG("\t--pca\n");
 		else
-			printLOG("\t--pca-no-norm\n");
+			LOG.printLOG("\t--pca-no-norm\n");
 
 		if (output_N_PCA_SNP_loadings != defaults.output_N_PCA_SNP_loadings)
-			printLOG("\t--pca-snp-loadings " + int2str(output_N_PCA_SNP_loadings) + "\n");
+			LOG.printLOG("\t--pca-snp-loadings " + output_log::int2str(output_N_PCA_SNP_loadings) + "\n");
 	}
-	if (output_prefix != defaults.output_prefix) printLOG("\t--out " + output_prefix + "\n");
-	if (output_relatedness) printLOG("\t--relatedness\n");
-	if (output_singletons) printLOG("\t--singletons\n");
-	if (output_site_depth) printLOG("\t--site-depth\n");
-	if (output_site_mean_depth) printLOG("\t--site-mean-depth\n");
-	if (output_site_pi != defaults.output_site_pi) printLOG("\t--site-pi\n");
-	if (output_site_quality) printLOG("\t--site-quality\n");
-	if (output_SNP_density_bin_size != defaults.output_SNP_density_bin_size) printLOG("\t--SNPdensity " + int2str(output_SNP_density_bin_size) + "\n");
-	if (output_TsTv_bin_size != defaults.output_TsTv_bin_size) printLOG("\t--TsTv " + int2str(output_TsTv_bin_size) + "\n");
-	if (output_TsTv_by_count) printLOG("\t--TsTv-by-count\n");
-	if (output_TsTv_by_qual) printLOG("\t--TsTv-by-qual\n");
-	if (phased_only) printLOG("\t--phased\n");
-	if (pi_window_size != defaults.pi_window_size) printLOG("\t--window-pi " + int2str(pi_window_size) + "\n");
-	if (plink_output) printLOG("\t--plink\n");
-	if (plink_tped_output) printLOG("\t--plink-tped\n");
-	if (positions_file != defaults.positions_file) printLOG("\t--positions " + positions_file + "\n");
-	if (recode) printLOG("\t--recode\n");
-	if (remove_all_filtered_genotypes) printLOG("\t--remove-filtered-geno-all\n");
-	if (remove_all_filtered_sites) printLOG("\t--remove-filtered-all\n");
-	if (snps_to_exclude_file != defaults.snps_to_exclude_file) printLOG("\t--exclude " + snps_to_exclude_file + "\n");
-	if (snps_to_keep_file != defaults.snps_to_keep_file) printLOG("\t--snps " + snps_to_keep_file + "\n");
-	if (start_pos != defaults.start_pos) printLOG("\t--from-bp " + int2str(start_pos) + "\n");
-	if (output_Tajima_D_bin_size != defaults.output_Tajima_D_bin_size) printLOG("\t--TajimaD " + int2str(output_Tajima_D_bin_size) + "\n");
+	if (output_prefix != defaults.output_prefix) LOG.printLOG("\t--out " + output_prefix + "\n");
+	if (output_relatedness) LOG.printLOG("\t--relatedness\n");
+	if (output_singletons) LOG.printLOG("\t--singletons\n");
+	if (output_site_depth) LOG.printLOG("\t--site-depth\n");
+	if (output_site_mean_depth) LOG.printLOG("\t--site-mean-depth\n");
+	if (output_site_pi != defaults.output_site_pi) LOG.printLOG("\t--site-pi\n");
+	if (output_site_quality) LOG.printLOG("\t--site-quality\n");
+	if (output_SNP_density_bin_size != defaults.output_SNP_density_bin_size) LOG.printLOG("\t--SNPdensity " + output_log::int2str(output_SNP_density_bin_size) + "\n");
+	if (output_TsTv_bin_size != defaults.output_TsTv_bin_size) LOG.printLOG("\t--TsTv " + output_log::int2str(output_TsTv_bin_size) + "\n");
+	if (output_TsTv_by_count) LOG.printLOG("\t--TsTv-by-count\n");
+	if (output_TsTv_by_qual) LOG.printLOG("\t--TsTv-by-qual\n");
+	if (phased_only) LOG.printLOG("\t--phased\n");
+	if (pi_window_size != defaults.pi_window_size) LOG.printLOG("\t--window-pi " + output_log::int2str(pi_window_size) + "\n");
+	if (plink_output) LOG.printLOG("\t--plink\n");
+	if (plink_tped_output) LOG.printLOG("\t--plink-tped\n");
+	if (positions_file != defaults.positions_file) LOG.printLOG("\t--positions " + positions_file + "\n");
+	if (recode) LOG.printLOG("\t--recode\n");
+	if (recode_to_stream) LOG.printLOG("\t--recode-to-stream\n");
+	if (remove_all_filtered_genotypes) LOG.printLOG("\t--remove-filtered-geno-all\n");
+	if (remove_all_filtered_sites) LOG.printLOG("\t--remove-filtered-all\n");
+	if (remove_indels != defaults.remove_indels) LOG.printLOG("\t--remove-indels\n");
+	if (snps_to_exclude_file != defaults.snps_to_exclude_file) LOG.printLOG("\t--exclude " + snps_to_exclude_file + "\n");
+	if (snps_to_keep_file != defaults.snps_to_keep_file) LOG.printLOG("\t--snps " + snps_to_keep_file + "\n");
+	if (start_pos != defaults.start_pos) LOG.printLOG("\t--from-bp " + output_log::int2str(start_pos) + "\n");
+	if (output_Tajima_D_bin_size != defaults.output_Tajima_D_bin_size) LOG.printLOG("\t--TajimaD " + output_log::int2str(output_Tajima_D_bin_size) + "\n");
 
-	if (output_as_ldhat_phased) printLOG("\t--ldhat\n");
-	if (output_as_ldhat_unphased) printLOG("\t--ldhat-geno\n");
+	if (output_as_ldhat_phased) LOG.printLOG("\t--ldhat\n");
+	if (output_as_ldhat_unphased) LOG.printLOG("\t--ldhat-geno\n");
 
 	if (site_filter_flags_to_exclude.size() > 0)
 		for (set<string>::iterator it=site_filter_flags_to_exclude.begin(); it != site_filter_flags_to_exclude.end(); ++it)
 		{
 			string tmp = *it;
-			printLOG("\t--remove-filtered " + tmp + "\n");
+			LOG.printLOG("\t--remove-filtered " + tmp + "\n");
 		}
 
 	if (site_filter_flags_to_keep.size() > 0)
 		for (set<string>::iterator it=site_filter_flags_to_keep.begin(); it != site_filter_flags_to_keep.end(); ++it)
 		{
 			string tmp = *it;
-			printLOG("\t--keep-filtered " + tmp + "\n");
+			LOG.printLOG("\t--keep-filtered " + tmp + "\n");
 		}
 
 	if (geno_filter_flags_to_exclude.size() > 0)
 		for (set<string>::iterator it=geno_filter_flags_to_exclude.begin(); it != geno_filter_flags_to_exclude.end(); ++it)
 		{
 			string tmp = *it;
-			printLOG("\t--remove-filtered-geno " + tmp + "\n");
+			LOG.printLOG("\t--remove-filtered-geno " + tmp + "\n");
 		}
 
 	if (INFO_to_extract.size() > 0)
 		for (unsigned int ui=0; ui<INFO_to_extract.size(); ui++)
-			printLOG("\t--get-INFO " + INFO_to_extract[ui] + "\n");
+			LOG.printLOG("\t--get-INFO " + INFO_to_extract[ui] + "\n");
 
 	if (diff_file != defaults.diff_file)
 	{
 		if (vcf_compressed == false)
-			printLOG("\t--diff " + diff_file + "\n");
+			LOG.printLOG("\t--diff " + diff_file + "\n");
 		else
-			printLOG("\t--gzdiff " + diff_file + "\n");
-		if (diff_site_discordance == true) printLOG("\t--diff-site-discordance\n");
-		if (diff_indv_discordance == true) printLOG("\t--diff-indv-discordance\n");
-		if (diff_discordance_matrix == true) printLOG("\t--diff-discordance-matrix\n");
-		if (diff_switch_error == true) printLOG("\t--diff-switch-error\n");
+			LOG.printLOG("\t--gzdiff " + diff_file + "\n");
+		if (diff_site_discordance == true) LOG.printLOG("\t--diff-site-discordance\n");
+		if (diff_indv_discordance == true) LOG.printLOG("\t--diff-indv-discordance\n");
+		if (diff_discordance_matrix == true) LOG.printLOG("\t--diff-discordance-matrix\n");
+		if (diff_switch_error == true) LOG.printLOG("\t--diff-switch-error\n");
 	}
 
 	if (recode_INFO_to_keep.size() > 0)
 		for (set<string>::iterator it=recode_INFO_to_keep.begin(); it != recode_INFO_to_keep.end(); ++it)
 		{
 			string tmp = *it;
-			printLOG("\t--recode-INFO " + tmp + "\n");
+			LOG.printLOG("\t--recode-INFO " + tmp + "\n");
 		}
 
 	if (site_INFO_flags_to_remove.size() > 0)
 		for (set<string>::iterator it=site_INFO_flags_to_remove.begin(); it != site_INFO_flags_to_remove.end(); ++it)
 		{
 			string tmp = *it;
-			printLOG("\t--remove-INFO " + tmp + "\n");
+			LOG.printLOG("\t--remove-INFO " + tmp + "\n");
 		}
 
 	if (site_INFO_flags_to_keep.size() > 0)
 		for (set<string>::iterator it=site_INFO_flags_to_keep.begin(); it != site_INFO_flags_to_keep.end(); ++it)
 		{
 			string tmp = *it;
-			printLOG("\t--keep-INFO " + tmp + "\n*** Note: --keep-INFO has changed. Are you sure you don't want --recode-INFO? ***\n");
+			LOG.printLOG("\t--keep-INFO " + tmp + "\n*** Note: --keep-INFO has changed. Are you sure you don't want --recode-INFO? ***\n");
 		}
 
 	if (BED_file != defaults.BED_file)
 	{
 		if (BED_exclude == false)
-			printLOG("\t--bed " + BED_file + "\n");
+			LOG.printLOG("\t--bed " + BED_file + "\n");
 		else
-			printLOG("\t--exclude-bed " + BED_file + "\n");
+			LOG.printLOG("\t--exclude-bed " + BED_file + "\n");
 	}
 
 	if (mask_file != defaults.mask_file)
 	{
 		if (invert_mask == false)
-			printLOG("\t--mask " + mask_file + "\n");
+			LOG.printLOG("\t--mask " + mask_file + "\n");
 		else
-			printLOG("\t--invert-mask " + mask_file + "\n");
+			LOG.printLOG("\t--invert-mask " + mask_file + "\n");
 	}
 
 	if (snps_to_keep.size() > 0)
 		for (set<string>::iterator it=snps_to_keep.begin(); it != snps_to_keep.end(); ++it)
 		{
 			string tmp = *it;
-			printLOG("\t--snp " + tmp + "\n");
+			LOG.printLOG("\t--snp " + tmp + "\n");
 		}
 
 	if (indv_to_keep.size() > 0)
 		for (set<string>::iterator it=indv_to_keep.begin(); it != indv_to_keep.end(); ++it)
 		{
 			string tmp = *it;
-			printLOG("\t--indv " + tmp + "\n");
+			LOG.printLOG("\t--indv " + tmp + "\n");
 		}
 
 	if (indv_to_exclude.size() > 0)
 		for (set<string>::iterator it=indv_to_exclude.begin(); it != indv_to_exclude.end(); ++it)
 		{
 			string tmp = *it;
-			printLOG("\t--remove-indv " + tmp + "\n");
+			LOG.printLOG("\t--remove-indv " + tmp + "\n");
 		}
 
-	printLOG("\n");
+	LOG.printLOG("\n");
 }
 
 void parameters::print_help()
@@ -483,6 +501,9 @@ void parameters::print_help()
 			cout << "For a list of options, please go to:" << endl;
 			cout << "\thttp://vcftools.sourceforge.net/options.html" << endl;
 			cout << endl;
+			cout << "Questions, comments, and suggestions should be emailed to:" << endl;
+			cout << "\tvcftools-help@lists.sourceforge.net" << endl;
+			cout << endl;
 
 			exit(0);
 		}
@@ -530,6 +551,6 @@ void parameters::check_parameters()
 
 void parameters::error(string err_msg, int code)
 {
-	printLOG("\n\nError: " + err_msg + "\n\n");
+	LOG.printLOG("\n\nError: " + err_msg + "\n\n");
 	exit(code);
 }
