@@ -70,7 +70,7 @@ void vcf_file::return_indv_union(vcf_file &file2, map<string, pair< int, int> >
 
 void vcf_file::output_sites_in_files(const string &output_file_prefix, vcf_file &diff_vcf_file)
 {
-	printLOG("Comparing sites in VCF files...\n");
+	LOG.printLOG("Comparing sites in VCF files...\n");
 	map<pair<string, int>, pair<int, int> > CHROMPOS_to_filepos_pair;
 	map<pair<string, int>, pair<int, int> >::iterator CHROMPOS_to_filepos_pair_it;
 	return_site_union(diff_vcf_file, CHROMPOS_to_filepos_pair);
@@ -121,7 +121,7 @@ void vcf_file::output_sites_in_files(const string &output_file_prefix, vcf_file
 			REF2 = REF;
 
 		if ((REF != REF2) && (REF2 != "N") && (REF != "N") && (REF != ".") && (REF2 != "."))
-			warning("Non-matching REF at " + CHROM + ":" + int2str(POS) + " " + REF + "/" + REF2 + ". Diff results may be unreliable.");
+			LOG.warning("Non-matching REF at " + CHROM + ":" + output_log::int2str(POS) + " " + REF + "/" + REF2 + ". Diff results may be unreliable.");
 
 		sites_in_files << CHROM << "\t" << POS << "\t";
 		if ((s1 != -1) && (s2 != -1))
@@ -140,27 +140,27 @@ void vcf_file::output_sites_in_files(const string &output_file_prefix, vcf_file
 			sites_in_files << "2";
 		}
 		else
-			error("SNP in neither file!?");
+			LOG.error("SNP in neither file!?");
 
 		sites_in_files << "\t" << REF << "\t" << e1.get_ALT() << "\t" << e2.get_ALT() << endl;
 	}
 
 	sites_in_files.close();
 
-	printLOG("Found " + int2str(N_common_SNPs) + " SNPs common to both files.\n");
-	printLOG("Found " + int2str(N_SNPs_file1_only) + " SNPs only in main file.\n");
-	printLOG("Found " + int2str(N_SNPs_file2_only) + " SNPs only in second file.\n");
+	LOG.printLOG("Found " + output_log::int2str(N_common_SNPs) + " SNPs common to both files.\n");
+	LOG.printLOG("Found " + output_log::int2str(N_SNPs_file1_only) + " SNPs only in main file.\n");
+	LOG.printLOG("Found " + output_log::int2str(N_SNPs_file2_only) + " SNPs only in second file.\n");
 }
 
 void vcf_file::output_indv_in_files(const string &output_file_prefix, vcf_file &diff_vcf_file)
 {
-	printLOG("Comparing individuals in VCF files...\n");
+	LOG.printLOG("Comparing individuals in VCF files...\n");
 
 	string output_file = output_file_prefix + ".diff.indv_in_files";
 
 	ofstream out(output_file.c_str());
 	if (!out.is_open())
-		error("Could not open Indv Differences File: " + output_file, 3);
+		LOG.error("Could not open Indv Differences File: " + output_file, 3);
 	out << "INDV\tFILES" << endl;
 
 	// Build a list of individuals contained in each file
@@ -188,19 +188,19 @@ void vcf_file::output_indv_in_files(const string &output_file_prefix, vcf_file &
 			out << combined_individuals_it->first << "\t2" << endl;
 		}
 		else
-			error("Unhandled case");
+			LOG.error("Unhandled case");
 	}
 	out.close();
 
-	printLOG("N_combined_individuals:\t" + int2str(N_combined_indv) + "\n");
-	printLOG("N_individuals_common_to_both_files:\t" + int2str(N[0]) + "\n");
-	printLOG("N_individuals_unique_to_file1:\t" + int2str(N[1]) + "\n");
-	printLOG("N_individuals_unique_to_file2:\t" + int2str(N[2]) + "\n");
+	LOG.printLOG("N_combined_individuals:\t" + output_log::int2str(N_combined_indv) + "\n");
+	LOG.printLOG("N_individuals_common_to_both_files:\t" + output_log::int2str(N[0]) + "\n");
+	LOG.printLOG("N_individuals_unique_to_file1:\t" + output_log::int2str(N[1]) + "\n");
+	LOG.printLOG("N_individuals_unique_to_file2:\t" + output_log::int2str(N[2]) + "\n");
 }
 
 void vcf_file::output_discordance_by_indv(const string &output_file_prefix, vcf_file &diff_vcf_file)
 {
-	printLOG("Outputting Discordance By Individual...\n");
+	LOG.printLOG("Outputting Discordance By Individual...\n");
 	map<pair<string, int>, pair<int, int> > CHROMPOS_to_filepos_pair;
 	map<pair<string, int>, pair<int, int> >::iterator CHROMPOS_to_filepos_pair_it;
 	return_site_union(diff_vcf_file, CHROMPOS_to_filepos_pair);
@@ -252,12 +252,12 @@ void vcf_file::output_discordance_by_indv(const string &output_file_prefix, vcf_
 
 		if (REF.size() != REF2.size())
 		{
-			warning("REF sequences at " + CHROM + ":" + int2str(POS) + " are not comparable. Skipping site");
+			LOG.warning("REF sequences at " + CHROM + ":" + output_log::int2str(POS) + " are not comparable. Skipping site");
 			continue;
 		}
 
 		if ((REF != REF2) && (REF2 != "N") && (REF != "N"))
-			warning("Non-matching REF " + CHROM + ":" + int2str(POS) + " " + REF + "/" + REF2);
+			LOG.warning("Non-matching REF " + CHROM + ":" + output_log::int2str(POS) + " " + REF + "/" + REF2);
 
 		// Do the alternative alleles match?
 		string ALT, ALT2;
@@ -315,7 +315,7 @@ void vcf_file::output_discordance_by_indv(const string &output_file_prefix, vcf_
 					// Don't do anything.
 				}
 				else
-					error("Unknown condition");
+					LOG.error("Unknown condition");
 			}
 			else
 			{	// Alleles don't match, so need to be more careful and compare strings
@@ -348,7 +348,7 @@ void vcf_file::output_discordance_by_indv(const string &output_file_prefix, vcf_
 					// Don't do anything
 				}
 				else
-					error("Unknown condition");
+					LOG.error("Unknown condition");
 			}
 		}
 	}
@@ -356,7 +356,7 @@ void vcf_file::output_discordance_by_indv(const string &output_file_prefix, vcf_
 	string output_file = output_file_prefix + ".diff.indv";
 	ofstream out(output_file.c_str());
 	if (!out.is_open())
-		error("Could not open Sites Differences File: " + output_file, 3);
+		LOG.error("Could not open Sites Differences File: " + output_file, 3);
 	out << "INDV\tN_COMMON_CALLED\tN_DISCORD\tDISCORDANCE" << endl;
 
 	int N, N_discord;
@@ -375,7 +375,7 @@ void vcf_file::output_discordance_by_indv(const string &output_file_prefix, vcf_
 
 void vcf_file::output_discordance_by_site(const string &output_file_prefix, vcf_file &diff_vcf_file)
 {
-	printLOG("Outputting Discordance By Site...\n");
+	LOG.printLOG("Outputting Discordance By Site...\n");
 	map<pair<string, int>, pair<int, int> > CHROMPOS_to_filepos_pair;
 	map<pair<string, int>, pair<int, int> >::iterator CHROMPOS_to_filepos_pair_it;
 	return_site_union(diff_vcf_file, CHROMPOS_to_filepos_pair);
@@ -391,8 +391,7 @@ void vcf_file::output_discordance_by_site(const string &output_file_prefix, vcf_
 	string output_file = output_file_prefix + ".diff.sites";
 	ofstream diffsites(output_file.c_str());
 	if (!diffsites.is_open())
-		error("Could not open Sites Differences File: " + output_file, 3);
-	//diffsites << "CHROM\tPOS\tFILES\tMATCHING_ALT\tN_COMMON_CALLED\tN_DISCORD\tDISCORDANCE\tN_FILE1_NONREF_GENOTYPES\tNON_REF_DISCORDANCE" << endl;
+		LOG.error("Could not open Sites Differences File: " + output_file, 3);
 	diffsites << "CHROM\tPOS\tFILES\tMATCHING_ALLELES\tN_COMMON_CALLED\tN_DISCORD\tDISCORDANCE" << endl;
 
 	for (CHROMPOS_to_filepos_pair_it=CHROMPOS_to_filepos_pair.begin(); CHROMPOS_to_filepos_pair_it != CHROMPOS_to_filepos_pair.end(); ++CHROMPOS_to_filepos_pair_it)
@@ -433,7 +432,7 @@ void vcf_file::output_discordance_by_site(const string &output_file_prefix, vcf_
 		else if ((s1 == -1) && (s2 != -1))
 			diffsites << "\t2";
 		else
-			error("Unhandled condition");
+			LOG.error("Unhandled condition");
 
 		e1.parse_basic_entry(true);
 		e2.parse_basic_entry(true);
@@ -448,12 +447,12 @@ void vcf_file::output_discordance_by_site(const string &output_file_prefix, vcf_
 
 		if (REF.size() != REF2.size())
 		{
-			warning("REF sequences at " + CHROM + ":" + int2str(POS) + " are not comparable. Skipping site");
+			LOG.warning("REF sequences at " + CHROM + ":" + output_log::int2str(POS) + " are not comparable. Skipping site");
 			continue;
 		}
 
 		if ((REF != REF2) && (REF2 != "N") && (REF != "N"))
-			warning("Non-matching REF " + CHROM + ":" + int2str(POS) + " " + REF + "/" + REF2);
+			LOG.warning("Non-matching REF " + CHROM + ":" + output_log::int2str(POS) + " " + REF + "/" + REF2);
 
 		// Do the alternative alleles match?
 		string ALT, ALT2;
@@ -518,7 +517,7 @@ void vcf_file::output_discordance_by_site(const string &output_file_prefix, vcf_
 					N_missing_1++;
 				}
 				else
-					error("Unknown condition");
+					LOG.error("Unknown condition");
 			}
 			else
 			{	// Alleles don't match, so need to be more careful and compare strings
@@ -551,7 +550,7 @@ void vcf_file::output_discordance_by_site(const string &output_file_prefix, vcf_
 					N_missing_1++;
 				}
 				else
-					error("Unknown condition");
+					LOG.error("Unknown condition");
 			}
 		}
 		double discordance = N_discord / double(N_common_called);
@@ -563,7 +562,7 @@ void vcf_file::output_discordance_by_site(const string &output_file_prefix, vcf_
 
 void vcf_file::output_discordance_matrix(const string &output_file_prefix, vcf_file &diff_vcf_file)
 {
-	printLOG("Outputting Discordance Matrix\n\tFor bi-allelic loci, called in both files, with matching alleles only...\n");
+	LOG.printLOG("Outputting Discordance Matrix\n\tFor bi-allelic loci, called in both files, with matching alleles only...\n");
 	map<pair<string, int>, pair<int, int> > CHROMPOS_to_filepos_pair;
 	map<pair<string, int>, pair<int, int> >::iterator CHROMPOS_to_filepos_pair_it;
 	return_site_union(diff_vcf_file, CHROMPOS_to_filepos_pair);
@@ -651,7 +650,7 @@ void vcf_file::output_discordance_matrix(const string &output_file_prefix, vcf_f
 			if (((geno_ids1.first != -1) && (geno_ids1.second == -1)) ||
 				((geno_ids2.first != -1) && (geno_ids2.second == -1)))
 			{	// Haploid
-				one_off_warning("***Warning: Haploid chromosomes not counted!***");
+				LOG.one_off_warning("***Warning: Haploid chromosomes not counted!***");
 				continue;
 			}
 
@@ -659,9 +658,9 @@ void vcf_file::output_discordance_matrix(const string &output_file_prefix, vcf_f
 			N2 = geno_ids2.first + geno_ids2.second;
 
 			if ((N1 == -1) || (N1 < -2) || (N1 > 2))
-				error("Unhandled case");
+				LOG.error("Unhandled case");
 			if ((N2 == -1) || (N2 < -2) || (N2 > 2))
-				error("Unhandled case");
+				LOG.error("Unhandled case");
 
 			if (N1 == -2)
 				N1 = 3;
@@ -676,7 +675,7 @@ void vcf_file::output_discordance_matrix(const string &output_file_prefix, vcf_f
 	string output_file = output_file_prefix + ".diff.discordance_matrix";
 	ofstream out(output_file.c_str());
 	if (!out.is_open())
-		error("Could not open Discordance Matrix File: " + output_file, 3);
+		LOG.error("Could not open Discordance Matrix File: " + output_file, 3);
 
 	out << "-\tN_0/0_file1\tN_0/1_file1\tN_1/1_file1\tN_./._file1" << endl;
 	out << "N_0/0_file2\t" << discordance_matrix[0][0] << "\t" << discordance_matrix[1][0] << "\t" << discordance_matrix[2][0] << "\t" << discordance_matrix[3][0] << endl;
@@ -688,7 +687,7 @@ void vcf_file::output_discordance_matrix(const string &output_file_prefix, vcf_f
 
 void vcf_file::output_switch_error(const string &output_file_prefix, vcf_file &diff_vcf_file)
 {
-	printLOG("Outputting Phase Switch Errors...\n");
+	LOG.printLOG("Outputting Phase Switch Errors...\n");
 	map<pair<string, int>, pair<int, int> > CHROMPOS_to_filepos_pair;
 	map<pair<string, int>, pair<int, int> >::iterator CHROMPOS_to_filepos_pair_it;
 	return_site_union(diff_vcf_file, CHROMPOS_to_filepos_pair);
@@ -704,7 +703,7 @@ void vcf_file::output_switch_error(const string &output_file_prefix, vcf_file &d
 	string output_file = output_file_prefix + ".diff.switch";
 	ofstream switcherror(output_file.c_str());
 	if (!switcherror.is_open())
-		error("Could not open Switch Error file: " + output_file, 4);
+		LOG.error("Could not open Switch Error file: " + output_file, 4);
 	switcherror << "CHROM\tPOS\tINDV" << endl;
 
 	unsigned int N_combined_indv = combined_individuals.size();
@@ -810,7 +809,7 @@ void vcf_file::output_switch_error(const string &output_file_prefix, vcf_file &d
 	output_file = output_file_prefix + ".diff.indv.switch";
 	ofstream idiscord(output_file.c_str());
 	if (!idiscord.is_open())
-		error("Could not open Individual Discordance File: " + output_file, 3);
+		LOG.error("Could not open Individual Discordance File: " + output_file, 3);
 
 	idiscord << "INDV\tN_COMMON_PHASED_HET\tN_SWITCH\tSWITCH" << endl;
 	unsigned int indv_count=0;
@@ -840,7 +839,7 @@ void vcf_file::output_switch_error(const string &output_file_prefix, vcf_file &d
 /*
 void vcf_file::output_concensus_statistics(const string &output_file_prefix, vcf_file &diff_vcf_file)
 {
-	printLOG("Outputting Consensus Statistics... \n");
+	LOG.printLOG("Outputting Consensus Statistics... \n");
 	unsigned int ui;
 
 	string output_file;
@@ -877,10 +876,10 @@ void vcf_file::output_concensus_statistics(const string &output_file_prefix, vcf
 	vector<int> indv_N_discord(N_combined_indv, 0);
 	vector<int> indv_N_called_sites(N_combined_indv, 0);
 
-	printLOG("N_combined_individuals:\t" + int2str(N_combined_indv) + "\n");
-	printLOG("N_individuals_common_to_both_files:\t" + int2str(N[0]) + "\n");
-	printLOG("N_individuals_unique_to_file1:\t" + int2str(N[1]) + "\n");
-	printLOG("N_individuals_unique_to_file2:\t" + int2str(N[2]) + "\n");
+	LOG.printLOG("N_combined_individuals:\t" + output_log::int2str(N_combined_indv) + "\n");
+	LOG.printLOG("N_individuals_common_to_both_files:\t" + output_log::int2str(N[0]) + "\n");
+	LOG.printLOG("N_individuals_unique_to_file1:\t" + output_log::int2str(N[1]) + "\n");
+	LOG.printLOG("N_individuals_unique_to_file2:\t" + output_log::int2str(N[2]) + "\n");
 
 	// Build a table of included entries in both files
 	map<pair<string, int>, pair<int, int> > CHROMPOS_to_filepos_pair;
@@ -922,9 +921,9 @@ void vcf_file::output_concensus_statistics(const string &output_file_prefix, vcf
 
 	sites_in_files.close();
 
-	printLOG("Found " + int2str(N_common_SNPs) + " SNPs common to both files.\n");
-	printLOG("Found " + int2str(N_SNPs_file1_only) + " SNPs only in main file.\n");
-	printLOG("Found " + int2str(N_SNPs_file2_only) + " SNPs only in second file.\n");
+	LOG.printLOG("Found " + output_log::int2str(N_common_SNPs) + " SNPs common to both files.\n");
+	LOG.printLOG("Found " + output_log::int2str(N_SNPs_file1_only) + " SNPs only in main file.\n");
+	LOG.printLOG("Found " + output_log::int2str(N_SNPs_file2_only) + " SNPs only in second file.\n");
 
 	output_file = output_file_prefix + ".diff.sites";
 	ofstream diffsites(output_file.c_str());
@@ -1004,12 +1003,12 @@ void vcf_file::output_concensus_statistics(const string &output_file_prefix, vcf
 
 		if (REF.size() != REF2.size())
 		{
-			warning("REF sequences at " + CHROM + ":" + int2str(POS) + " are not comparable. Skipping site");
+			warning("REF sequences at " + CHROM + ":" + output_log::int2str(POS) + " are not comparable. Skipping site");
 			continue;
 		}
 
 		if ((REF != REF2) && (REF2 != "N") && (REF != "N"))
-			warning("Non-matching REF " + CHROM + ":" + int2str(POS) + " " + REF + "/" + REF2);
+			warning("Non-matching REF " + CHROM + ":" + output_log::int2str(POS) + " " + REF + "/" + REF2);
 
 		// Do the alternative alleles match?
 		set<string> ALT1, ALT2;
@@ -1263,20 +1262,20 @@ void vcf_file::output_concensus_statistics(const string &output_file_prefix, vcf
 	}
 	idiscord.close();
 
-	printLOG("Found " + int2str(N_sites_with_mismatching_ALT) + " sites with mismatching ALT alleles.\n");
+	LOG.printLOG("Found " + output_log::int2str(N_sites_with_mismatching_ALT) + " sites with mismatching ALT alleles.\n");
 
-	printLOG("Found " + int2str(N_non_ref_genotypes) + " non-reference genotypes called in both files.\n");
-	printLOG("Found " + int2str(N_discordant_non_ref_genotypes) + " discordant non-reference genotypes.\n");
+	LOG.printLOG("Found " + output_log::int2str(N_non_ref_genotypes) + " non-reference genotypes called in both files.\n");
+	LOG.printLOG("Found " + output_log::int2str(N_discordant_non_ref_genotypes) + " discordant non-reference genotypes.\n");
 	double concordance = 1.0 - (double(N_discordant_non_ref_genotypes)) / N_non_ref_genotypes;
-	printLOG("Concordance rate: " + dbl2str_fixed(concordance * 100,2) + "%\n");
+	LOG.printLOG("Concordance rate: " + dbl2str_fixed(concordance * 100,2) + "%\n");
 
-	printLOG("Found " + int2str(N_common_genotypes) + " genotypes called in both files.\n");
-	printLOG("Found " + int2str(N_common_discordant_genotypes) + " discordant genotypes.\n");
+	LOG.printLOG("Found " + output_log::int2str(N_common_genotypes) + " genotypes called in both files.\n");
+	LOG.printLOG("Found " + output_log::int2str(N_common_discordant_genotypes) + " discordant genotypes.\n");
 	concordance = 1.0 - (double(N_common_discordant_genotypes)) / N_common_genotypes;
-	printLOG("Overall Concordance rate: " + dbl2str_fixed(concordance * 100,2) + "%\n");
+	LOG.printLOG("Overall Concordance rate: " + dbl2str_fixed(concordance * 100,2) + "%\n");
 
 	diffsites.close();
 	switcherror.close();
-	printLOG("Done\n");
+	LOG.printLOG("Done\n");
 }
 */
