@@ -10,13 +10,14 @@
 
 void vcf_file::apply_filters(const parameters &params)
 {
-	printLOG("Applying Required Filters.\n");
+	LOG.printLOG("Applying Required Filters.\n");
 	// Apply all filters in turn.
 	filter_individuals(params.indv_to_keep, params.indv_to_exclude, params.indv_keep_file, params.indv_exclude_file);
+	filter_sites_by_allele_type(params.keep_only_indels, params.remove_indels);
 	filter_sites(params.snps_to_keep, params.snps_to_keep_file, params.snps_to_exclude_file);
 	filter_sites_by_filter_status(params.site_filter_flags_to_exclude, params.site_filter_flags_to_keep, params.remove_all_filtered_sites);
 	filter_sites_by_position(params.chr_to_keep, params.start_pos, params.end_pos);
-	filter_sites_by_positions(params.positions_file);
+	filter_sites_by_positions(params.positions_file, params.exclude_positions_file);
 	filter_sites_by_BED_file(params.BED_file, params.BED_exclude);
 	filter_sites_by_number_of_alleles(params.min_alleles, params.max_alleles);
 	filter_sites_by_INFO_flags(params.site_INFO_flags_to_remove, params.site_INFO_flags_to_keep);
@@ -47,9 +48,9 @@ void vcf_file::filter_genotypes_by_quality(double min_genotype_quality)
 		return;
 
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to filter genotypes by Quality.");
+		LOG.error("Require Genotypes in VCF file in order to filter genotypes by Quality.");
 
-	printLOG("Filtering out Genotypes with Quality less than " + dbl2str(min_genotype_quality,0) + "\n");
+	LOG.printLOG("Filtering out Genotypes with Quality less than " + output_log::dbl2str(min_genotype_quality,0) + "\n");
 	string vcf_line;
 	vcf_entry e(N_indv);
 	for (unsigned int s=0; s<N_entries; s++)
@@ -70,9 +71,9 @@ void vcf_file::filter_genotypes_by_depth(int min_depth, int max_depth)
 	if ((min_depth <= 0) && (max_depth == numeric_limits<int>::max()))
 		return;
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to filter genotypes by Depth.");
+		LOG.error("Require Genotypes in VCF file in order to filter genotypes by Depth.");
 
-	printLOG("Filtering out Genotypes with Depth less than " + dbl2str(min_depth,0) + " and greater than " + dbl2str(max_depth, 0) + "\n");
+	LOG.printLOG("Filtering out Genotypes with Depth less than " + output_log::dbl2str(min_depth,0) + " and greater than " + output_log::dbl2str(max_depth, 0) + "\n");
 	string vcf_line;
 	vcf_entry e(N_indv);
 	for (unsigned int s=0; s<N_entries; s++)
@@ -93,12 +94,12 @@ void vcf_file::filter_genotypes_by_filter_flag(const set<string> &filter_flags_t
 	if ((remove_all == false) && (filter_flags_to_remove.size() == 0))
 		return;
 	if (remove_all == true)
-		printLOG("Filtering out all genotypes with FILTER flag.\n");
+		LOG.printLOG("Filtering out all genotypes with FILTER flag.\n");
 	else
-		printLOG("Filtering out genotypes by Filter Status.\n");
+		LOG.printLOG("Filtering out genotypes by Filter Status.\n");
 
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to filter genotypes by Filter Flag.");
+		LOG.error("Require Genotypes in VCF file in order to filter genotypes by Filter Flag.");
 
 	string vcf_line;
 	vcf_entry e(N_indv);
@@ -135,13 +136,13 @@ void vcf_file::filter_individuals_by_keep_list(const set<string> &indv_to_keep,
 	// Filter individuals by user provided list
 	if ((indv_to_keep_filename == "") && (indv_to_keep.size() == 0))
 		return;
-	printLOG("Keeping individuals in 'keep' list\n");
+	LOG.printLOG("Keeping individuals in 'keep' list\n");
 	set<string> indv_to_keep_copy = indv_to_keep;
 	if (indv_to_keep_filename != "")
 	{
 		ifstream infile(indv_to_keep_filename.c_str());
 		if (!infile.is_open())
-			error("Could not open Individual file:" + indv_to_keep_filename, 1);
+			LOG.error("Could not open Individual file:" + indv_to_keep_filename, 1);
 		string line;
 		string tmp_indv;
 		stringstream ss;
@@ -170,14 +171,14 @@ void vcf_file::filter_individuals_by_exclude_list(const set<string> &indv_to_exc
 	// Filter individuals by user provided list
 	if ((indv_to_exclude_filename == "") && (indv_to_exclude.size() == 0))
 		return;
-	printLOG("Excluding individuals in 'exclude' list\n");
+	LOG.printLOG("Excluding individuals in 'exclude' list\n");
 	set<string> indv_to_exclude_copy = indv_to_exclude;
 	if (indv_to_exclude_filename != "")
 	{
 		ifstream infile(indv_to_exclude_filename.c_str());
 		if (!infile.is_open())
 		{
-			error("Could not open Individual file:" + indv_to_exclude_filename, 1);
+			LOG.error("Could not open Individual file:" + indv_to_exclude_filename, 1);
 		}
 		string line;
 		string tmp_indv;
@@ -208,9 +209,9 @@ void vcf_file::filter_individuals_by_call_rate(double min_call_rate)
 		return;
 
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to filter individuals by call rate.");
+		LOG.error("Require Genotypes in VCF file in order to filter individuals by call rate.");
 
-	printLOG("Filtering individuals by call rate\n");
+	LOG.printLOG("Filtering individuals by call rate\n");
 
 	unsigned int ui;
 	pair<int, int> genotype;
@@ -261,9 +262,9 @@ void vcf_file::filter_individuals_by_mean_depth(double min_mean_depth, double ma
 		return;
 
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to filter individuals by mean depth");
+		LOG.error("Require Genotypes in VCF file in order to filter individuals by mean depth");
 
-	printLOG("Filtering individuals by mean depth\n");
+	LOG.printLOG("Filtering individuals by mean depth\n");
 	unsigned int ui;
 
 	vector<int> N_sites_included(N_indv, 0);
@@ -310,10 +311,10 @@ void vcf_file::filter_individuals_by_phase()
 {
 	// Filter individuals that are completely unphased.
 	// TODO: Alter this to allow for a max/min level of unphased-ness.
-	printLOG("Filtering Unphased Individuals\n");
+	LOG.printLOG("Filtering Unphased Individuals\n");
 
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file to filter by Phase.");
+		LOG.error("Require Genotypes in VCF file to filter by Phase.");
 
 	unsigned int ui, s;
 	vector<unsigned int> indv_count(N_indv, 0);
@@ -358,10 +359,10 @@ void vcf_file::filter_individuals_randomly(int max_N_indv)
 	// Filter individuals randomly until have a random subset
 	if (max_N_indv < 0)
 		return;
-	printLOG("Filtering Individuals Randomly\n");
+	LOG.printLOG("Filtering Individuals Randomly\n");
 
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file filter individuals.");
+		LOG.error("Require Genotypes in VCF file filter individuals.");
 
 	unsigned int N_kept_indv = N_kept_individuals();
 
@@ -421,7 +422,7 @@ void vcf_file::filter_sites_to_keep(const set<string> &snps_to_keep, const strin
 
 	set<string> local_snps_to_keep = snps_to_keep;
 
-	printLOG("Keeping sites by user-supplied list\n");
+	LOG.printLOG("Keeping sites by user-supplied list\n");
 
 	if (snps_to_keep_file != "")
 	{
@@ -429,7 +430,7 @@ void vcf_file::filter_sites_to_keep(const set<string> &snps_to_keep, const strin
 		string tmp;
 		if (!in.is_open())
 		{
-			error("Could not open SNPs to Keep file" + snps_to_keep_file, 0);
+			LOG.error("Could not open SNPs to Keep file" + snps_to_keep_file, 0);
 		}
 		while (!in.eof())
 		{
@@ -461,7 +462,7 @@ void vcf_file::filter_sites_to_exclude(const string &snps_to_exclude_file)
 	if (snps_to_exclude_file == "")
 		return;
 
-	printLOG("Excluding sites by user-supplied list\n");
+	LOG.printLOG("Excluding sites by user-supplied list\n");
 
 	set<string> snps_to_exclude;
 	if (snps_to_exclude_file != "")
@@ -470,7 +471,7 @@ void vcf_file::filter_sites_to_exclude(const string &snps_to_exclude_file)
 		string tmp;
 		if (!in.is_open())
 		{
-			error("Could not open SNPs to Exclude file" + snps_to_exclude_file, 0);
+			LOG.error("Could not open SNPs to Exclude file" + snps_to_exclude_file, 0);
 		}
 		while (!in.eof())
 		{
@@ -501,7 +502,7 @@ void vcf_file::filter_sites_by_quality(double min_quality)
 	if (min_quality < 0)
 		return;
 
-	printLOG("Filtering sites with Quality less than " + dbl2str(min_quality,0) + "\n");
+	LOG.printLOG("Filtering sites with Quality less than " + output_log::dbl2str(min_quality,0) + "\n");
 
 	unsigned int s;
 	string vcf_line;
@@ -538,9 +539,9 @@ void vcf_file::filter_sites_by_mean_depth(double min_mean_depth, double max_mean
 		return;
 
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to filter sites by mean depth");
+		LOG.error("Require Genotypes in VCF file in order to filter sites by mean depth");
 
-	printLOG("Filtering sites by mean depth\n");
+	LOG.printLOG("Filtering sites by mean depth\n");
 	int depth;
 
 	string vcf_line;
@@ -582,16 +583,13 @@ void vcf_file::filter_sites_by_position(const string &chr, int start_pos, int en
 	// Filter sites by user provided position range
 	if ((chr == "") || ((start_pos == -1) && (end_pos==numeric_limits<int>::max())))
 		return;
-	printLOG("Filtering sites by chromosome and/or position\n");
+	LOG.printLOG("Filtering sites by chromosome and/or position\n");
 	string vcf_line;
 	string chrom; int pos1;
 	for (unsigned int s=0; s<N_entries; s++)
 	{
 		if (include_entry[s] == false)
 			continue;
-		//get_vcf_entry(s, vcf_line);
-		//vcf_entry e(N_indv, vcf_line);
-		//e.parse_basic_entry();
 		set_filepos(entry_file_locations[s]);
 		read_CHROM_and_POS_only(chrom, pos1);
 		if (chrom == chr)
@@ -604,72 +602,121 @@ void vcf_file::filter_sites_by_position(const string &chr, int start_pos, int en
 	}
 }
 
-void vcf_file::filter_sites_by_positions(const string &positions_file)
+void vcf_file::filter_sites_by_positions(const string &positions_file, const string &exclude_positions_file)
 {
 	// Filter sites by a user defined file containing a list of positions
-	if (positions_file == "")
+	if ((positions_file == "") && (exclude_positions_file == ""))
 		return;
-	printLOG("Filtering sites by Positions file\n");
-	ifstream BED(positions_file.c_str());
-	if (!BED.is_open())
-		error("Could not open Positions file: " + positions_file);
+	LOG.printLOG("Filtering sites by include/exclude positions files\n");
 
 	string chr;
-	int pos1;
-	int idx;
+	int pos1, idx;
 	unsigned int N_chr=0;
 	map<string,int> chr_to_idx;
-	vector< set<int > > lims;
+	bool keep=false, exclude=false;
+	vector< set<int > > keep_positions, exclude_positions;
 	stringstream ss;
-	string line;
-	// Skip header
-	BED.ignore(numeric_limits<streamsize>::max(), '\n');
-	while (!BED.eof())
+	string line, vcf_line;
+
+	if (positions_file != "")
 	{
-		getline(BED, line);
-		if (line[0] == '#')
-			continue;
+		ifstream BED(positions_file.c_str());
+		if (!BED.is_open())
+			LOG.error("Could not open Positions file: " + positions_file);
+		keep = true;
 
-		ss.clear();
-		ss.str(line);
-		ss >> chr >> pos1;
-
-		if (chr_to_idx.find(chr) == chr_to_idx.end())
+		// Skip header
+		BED.ignore(numeric_limits<streamsize>::max(), '\n');
+		while (!BED.eof())
 		{
-			N_chr++;
-			chr_to_idx[chr] = (N_chr-1);
-			lims.resize(N_chr);
+			getline(BED, line);
+			if (line[0] == '#')
+				continue;
+
+			ss.clear();
+			ss.str(line);
+			ss >> chr >> pos1;
+
+			if (chr_to_idx.find(chr) == chr_to_idx.end())
+			{
+				N_chr++;
+				chr_to_idx[chr] = (N_chr-1);
+				keep_positions.resize(N_chr);
+			}
+
+			idx = chr_to_idx[chr];
+			keep_positions[idx].insert(pos1);
 		}
+		BED.close();
+	}
 
-		idx = chr_to_idx[chr];
-		lims[idx].insert(pos1);
+	if (exclude_positions_file != "")
+	{
+		ifstream BED(exclude_positions_file.c_str());
+		if (!BED.is_open())
+			LOG.error("Could not open Positions file: " + exclude_positions_file);
+		exclude = true;
+
+		// Skip header
+		BED.ignore(numeric_limits<streamsize>::max(), '\n');
+		while (!BED.eof())
+		{
+			getline(BED, line);
+			if (line[0] == '#')
+				continue;
+
+			ss.clear();
+			ss.str(line);
+			ss >> chr >> pos1;
+
+			if (chr_to_idx.find(chr) == chr_to_idx.end())
+			{
+				N_chr++;
+				chr_to_idx[chr] = (N_chr-1);
+				exclude_positions.resize(N_chr);
+			}
+
+			idx = chr_to_idx[chr];
+			exclude_positions[idx].insert(pos1);
+		}
+		BED.close();
 	}
-	BED.close();
 
-	string vcf_line;
 	for (unsigned int s=0; s<N_entries; s++)
 	{
 		if (include_entry[s] == false)
 			continue;
-		//get_vcf_entry(s, vcf_line);
-		//vcf_entry e(N_indv, vcf_line);
-		//e.parse_basic_entry();
-		//e.get_CHROM(chr);
 		set_filepos(entry_file_locations[s]);
 		read_CHROM_and_POS_only(chr, pos1);
-		if (chr_to_idx.find(chr) == chr_to_idx.end())
-			include_entry[s] = false;
-		else
-		{
-			//pos1 = e.get_POS();
-			idx = chr_to_idx[chr];
-			bool found=false;
-
-			if (lims[idx].find(pos1) != lims[idx].end())
-				found = true;
-
-			if (found == false)
+		if (keep == true)
+		{	// Check to see if position is in keep list
+			if (chr_to_idx.find(chr) == chr_to_idx.end())
 				include_entry[s] = false;
+			else
+			{
+				idx = chr_to_idx[chr];
+				bool found=false;
+
+				if (keep_positions[idx].find(pos1) != keep_positions[idx].end())
+					found = true;
+
+				if (found == false)
+					include_entry[s] = false;
+			}
+		}
+		if (exclude == true)
+		{	// Check to see if position is in exclude list
+			if (chr_to_idx.find(chr) != chr_to_idx.end())
+			{
+				idx = chr_to_idx[chr];
+				bool found=false;
+
+				if (exclude_positions[idx].find(pos1) != exclude_positions[idx].end())
+					found = true;
+
+				if (found == true)
+					include_entry[s] = false;
+			}
 		}
 	}
 }
@@ -679,10 +726,10 @@ void vcf_file::filter_sites_by_BED_file(const string &bed_file, bool BED_exclude
 	// Filter sites depending on positions in a BED file.
 	if (bed_file == "")
 		return;
-	printLOG("Filtering sites by BED file\n");
+	LOG.printLOG("Filtering sites by BED file\n");
 	ifstream BED(bed_file.c_str());
 	if (!BED.is_open())
-		error("Could not open BED file: " + bed_file);
+		LOG.error("Could not open BED file: " + bed_file);
 
 	string chr;
 	int pos1, pos2;
@@ -691,6 +738,7 @@ void vcf_file::filter_sites_by_BED_file(const string &bed_file, bool BED_exclude
 	map<string,int> chr_to_idx;
 	vector< deque<pair<int,int> > > lims;
 	BED.ignore(numeric_limits<streamsize>::max(), '\n');	// Ignore header
+	unsigned int N_BED_entries=0;
 	while (!BED.eof())
 	{
 		BED >> chr >> pos1 >> pos2;
@@ -705,9 +753,12 @@ void vcf_file::filter_sites_by_BED_file(const string &bed_file, bool BED_exclude
 
 		idx = chr_to_idx[chr];
 		lims[idx].push_back(make_pair(pos1,pos2));
+		N_BED_entries++;
 	}
 	BED.close();
 
+	LOG.printLOG("\tRead " + output_log::int2str(N_BED_entries) + " BED file entries.\n");
+
 	for (unsigned int ui=0; ui<lims.size(); ui++)
 		sort(lims[ui].begin(), lims[ui].end());
 
@@ -777,12 +828,12 @@ void vcf_file::filter_sites_by_mask(const string &mask_file, bool invert_mask, i
 	if (mask_file == "")
 		return;
 	if (invert_mask == false)
-		printLOG("Filtering sites by mask file\n");
+		LOG.printLOG("Filtering sites by mask file\n");
 	else
-		printLOG("Filtering sites by inverted mask file\n");
+		LOG.printLOG("Filtering sites by inverted mask file\n");
 	ifstream mask(mask_file.c_str());
 	if (!mask.is_open())
-		error("Could not open mask file: " + mask_file);
+		LOG.error("Could not open mask file: " + mask_file);
 
 	string line;
 	string next_chr="", vcf_line;
@@ -875,7 +926,7 @@ void vcf_file::filter_sites_by_number_of_alleles(int min_alleles, int max_allele
 	// Filter sites by the number of alleles (e.g. 2 for bi-allelic)
 	if ((min_alleles <= 0) && (max_alleles == numeric_limits<int>::max()))
 		return;
-	printLOG("Filtering sites by number of alleles\n");
+	LOG.printLOG("Filtering sites by number of alleles\n");
 
 	int N_alleles;
 	string vcf_line;
@@ -902,9 +953,9 @@ void vcf_file::filter_sites_by_frequency_and_call_rate(double min_maf, double ma
 		return;
 
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file to filter by frequency and/or call rate");
+		LOG.error("Require Genotypes in VCF file to filter by frequency and/or call rate");
 
-	printLOG("Filtering sites by allele frequency and call rate\n");
+	LOG.printLOG("Filtering sites by allele frequency and call rate\n");
 
 	unsigned int N_alleles;
 	unsigned int N_non_missing_chr;
@@ -949,6 +1000,55 @@ void vcf_file::filter_sites_by_frequency_and_call_rate(double min_maf, double ma
 	}
 }
 
+void vcf_file::filter_sites_by_allele_type(bool keep_only_indels, bool remove_indels)
+{
+	if ((keep_only_indels == false) && (remove_indels == false))
+		return;
+	if ((keep_only_indels == true) && (remove_indels == true))
+		LOG.error("Can't both keep and remove all indels!");
+	LOG.printLOG("Filtering sites by allele type\n");
+
+	string vcf_line;
+	vcf_entry e(N_indv);
+	string allele;
+	unsigned int ref_len, N_alleles;
+	bool is_indel;
+	for (unsigned int s=0; s<N_entries; s++)
+	{
+		if (include_entry[s] == false)
+			continue;
+
+		get_vcf_entry(s, vcf_line);
+		e.reset(vcf_line);
+		e.parse_basic_entry(true);
+
+		is_indel = false;
+		allele = e.get_REF();
+		ref_len = allele.size();
+		N_alleles = e.get_N_alleles();
+		for (unsigned int ui=1; ui<N_alleles; ui++)
+		{
+			e.get_allele(ui, allele);
+			if (allele.size() != ref_len)
+			{
+				is_indel = true;
+				break;
+			}
+		}
+
+		if (keep_only_indels == true)
+		{
+			if (is_indel == false)
+				include_entry[s] = false;
+		}
+		else if (remove_indels == true)
+		{
+			if (is_indel == true)
+				include_entry[s] = false;
+		}
+	}
+}
+
 
 
 void vcf_file::filter_sites_by_allele_count(double min_mac, double max_mac, double min_non_ref_ac, double max_non_ref_ac, double max_missing_call_count)
@@ -960,9 +1060,9 @@ void vcf_file::filter_sites_by_allele_count(double min_mac, double max_mac, doub
 
 	// Filter sites so that all allele counts are between limits
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file to filter by allele counts and/or missing data");
+		LOG.error("Require Genotypes in VCF file to filter by allele counts and/or missing data");
 
-	printLOG("Filtering sites by allele count and missing data\n");
+	LOG.printLOG("Filtering sites by allele count and missing data\n");
 
 	unsigned int N_alleles, N_chr, N_non_missing_chr;
 
@@ -1007,10 +1107,10 @@ void vcf_file::filter_sites_by_HWE_pvalue(double min_HWE_pvalue)
 		return;
 
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file to filter sites by HWE.");
+		LOG.error("Require Genotypes in VCF file to filter sites by HWE.");
 
 	// Note this assumes Biallelic SNPs.
-	printLOG("Filtering sites by HWE p-value (only including bi-allelic sites)\n");
+	LOG.printLOG("Filtering sites by HWE p-value (only including bi-allelic sites)\n");
 
 	unsigned int b11, b12, b22;
 	double p;
@@ -1040,7 +1140,7 @@ void vcf_file::filter_sites_by_filter_status(const set<string> &filter_flags_to_
 	if ((remove_all == false) && (filter_flags_to_remove.size() == 0) && (filter_flags_to_keep.size() == 0))
 		return;
 
-	printLOG("Filtering sites by FILTER Status.\n");
+	LOG.printLOG("Filtering sites by FILTER Status.\n");
 
 	vector<string> FILTERs;
 	string vcf_line;
@@ -1088,7 +1188,7 @@ void vcf_file::filter_sites_by_phase()
 {
 	// Filter out sites with unphased entries
 	// TODO: Alter this to allow for a max/min level of unphased-ness.
-	printLOG("Filtering Sites with Unphased Genotypes\n");
+	LOG.printLOG("Filtering Sites with Unphased Genotypes\n");
 	string vcf_line;
 	vcf_entry e(N_indv);
 
@@ -1124,7 +1224,7 @@ void vcf_file::filter_sites_by_thinning(int min_SNP_distance)
 	// Filter sites so that no two SNPs are within some minimum distance
 	if (min_SNP_distance < 1)
 		return;
-	printLOG("Filtering sites so that no two sites are within " + int2str(min_SNP_distance) + "bp\n");
+	LOG.printLOG("Filtering sites so that no two sites are within " + output_log::int2str(min_SNP_distance) + "bp\n");
 
 	string vcf_line;
 	vcf_entry e(N_indv);
@@ -1138,12 +1238,6 @@ void vcf_file::filter_sites_by_thinning(int min_SNP_distance)
 		if (include_entry[s] == false)
 			continue;
 
-		//get_vcf_entry(s, vcf_line);
-		//e.reset(vcf_line);
-		//e.parse_basic_entry();
-
-		//CHROM = e.get_CHROM();
-		//POS = e.get_POS();
 		set_filepos(entry_file_locations[s]);
 		read_CHROM_and_POS_only(CHROM, POS);
 		if (CHROM == last_CHROM)
@@ -1165,7 +1259,7 @@ void vcf_file::filter_sites_by_INFO_flags(const set<string> &flags_to_remove, co
 	if ((flags_to_remove.size() == 0) && (flags_to_keep.size() == 0))
 		return;
 
-	printLOG("Filtering sites by INFO flags.\n");
+	LOG.printLOG("Filtering sites by INFO flags.\n");
 
 	vector<string> INFOs;
 	string vcf_line;
