@@ -11,14 +11,14 @@ void vcf_file::output_as_plink(const string &output_file_prefix)
 {
 	// Output as PLINK formatted PED/MAP files.
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to output as PLINK.");
+		LOG.error("Require Genotypes in VCF file in order to output as PLINK.");
 
-	printLOG("Writing PLINK PED file ... ");
+	LOG.printLOG("Writing PLINK PED file ... ");
 	string ped_file = output_file_prefix + ".ped";
 	string map_file = output_file_prefix + ".map";
 
 	ofstream PED(ped_file.c_str());
-	if (!PED.is_open()) error("Could not open output file: " + ped_file, 12);
+	if (!PED.is_open()) LOG.error("Could not open output file: " + ped_file, 12);
 
 	vector<string> alleles;
 	char phase;
@@ -75,9 +75,9 @@ void vcf_file::output_as_plink(const string &output_file_prefix)
 
 	PED.close();
 
-	printLOG("Writing PLINK MAP file ... ");
+	LOG.printLOG("Writing PLINK MAP file ... ");
 	ofstream MAP(map_file.c_str());
-	if (!MAP.is_open()) error("Could not open output file: " + map_file, 12);
+	if (!MAP.is_open()) LOG.error("Could not open output file: " + map_file, 12);
 	for (unsigned int s=0; s<N_entries; s++)
 	{
 		if (include_entry[s] == false)
@@ -96,7 +96,7 @@ void vcf_file::output_as_plink(const string &output_file_prefix)
 	}
 
 	MAP.close();
-	printLOG("Done.\n");
+	LOG.printLOG("Done.\n");
 }
 */
 
@@ -104,9 +104,9 @@ void vcf_file::output_as_plink(const string &output_file_prefix)
 {
 	// Output as PLINK formatted PED/MAP files.
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to output as PLINK.");
+		LOG.error("Require Genotypes in VCF file in order to output as PLINK.");
 
-	printLOG("Writing PLINK PED file ... \n");
+	LOG.printLOG("Writing PLINK PED file ... \n");
 	string ped_file = output_file_prefix + ".ped";
 	string map_file = output_file_prefix + ".map";
 
@@ -119,7 +119,7 @@ void vcf_file::output_as_plink(const string &output_file_prefix)
 		string filename(tmpnam(NULL));
 		ofstream *tmp_file = new ofstream(filename.c_str());
 		if (!tmp_file->good())
-			error("\n\nCould not open temporary file.\n\n"
+			LOG.error("\n\nCould not open temporary file.\n\n"
 					"Most likely this is because the system is not allowing me to open enough temporary files.\n"
 					"Try using ulimit -n <int> to increase the number of allowed open files.\n"
 					"Alternatively, try the --plink-tped command.", 12);
@@ -145,7 +145,7 @@ void vcf_file::output_as_plink(const string &output_file_prefix)
 
 		if (e.get_N_alleles() > 2)
 		{
-			one_off_warning("\tPLINK: Only outputting biallelic loci.");
+			LOG.one_off_warning("\tPLINK: Only outputting biallelic loci.");
 			continue;
 		}
 
@@ -187,7 +187,7 @@ void vcf_file::output_as_plink(const string &output_file_prefix)
 	}
 
 	ofstream PED(ped_file.c_str());
-	if (!PED.is_open()) error("Could not open output file: " + ped_file, 12);
+	if (!PED.is_open()) LOG.error("Could not open output file: " + ped_file, 12);
 	string tmp_line;
 	for (unsigned int ui=0; ui<N_indv; ui++)
 	{
@@ -200,7 +200,7 @@ void vcf_file::output_as_plink(const string &output_file_prefix)
 
 		ifstream read_file(tmp_filenames[ui].c_str());
 		if (!read_file.good())
-			error("\n\nCould not open temporary file.\n\n"
+			LOG.error("\n\nCould not open temporary file.\n\n"
 					"Most likely this is because the system is not allowing me to open enough temporary files.\n"
 					"Try using ulimit -n <int> to increase the number of allowed open files.\n"
 					"Alternatively, try the --plink-tped command.", 12);
@@ -211,9 +211,9 @@ void vcf_file::output_as_plink(const string &output_file_prefix)
 	}
 	PED.close();
 
-	printLOG("Writing PLINK MAP file ... ");
+	LOG.printLOG("Writing PLINK MAP file ... ");
 	ofstream MAP(map_file.c_str());
-	if (!MAP.is_open()) error("Could not open output file: " + map_file, 12);
+	if (!MAP.is_open()) LOG.error("Could not open output file: " + map_file, 12);
 	int POS; string ID;
 	for (unsigned int s=0; s<N_entries; s++)
 	{
@@ -234,7 +234,7 @@ void vcf_file::output_as_plink(const string &output_file_prefix)
 	}
 
 	MAP.close();
-	printLOG("Done.\n");
+	LOG.printLOG("Done.\n");
 }
 
 // Output as Plink Transposed file
@@ -242,14 +242,14 @@ void vcf_file::output_as_plink_tped(const string &output_file_prefix)
 {
 	// Output as PLINK formatted PED/MAP files.
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to output as PLINK TPED.");
+		LOG.error("Require Genotypes in VCF file in order to output as PLINK TPED.");
 
-	printLOG("Writing PLINK TPED file ... ");
+	LOG.printLOG("Writing PLINK TPED file ... ");
 	string tped_file = output_file_prefix + ".tped";
 	string tfam_file = output_file_prefix + ".tfam";
 
 	ofstream TPED(tped_file.c_str());
-	if (!TPED.is_open()) error("Could not open output file: " + tped_file, 12);
+	if (!TPED.is_open()) LOG.error("Could not open output file: " + tped_file, 12);
 
 	vector<string> alleles;
 	char phase;
@@ -267,7 +267,7 @@ void vcf_file::output_as_plink_tped(const string &output_file_prefix)
 
 		if (e.get_N_alleles() > 2)	// Only output sites with at most one alternative allele
 		{
-			one_off_warning("\tPLINK-TPED: Only outputting biallelic loci.");
+			LOG.one_off_warning("\tPLINK-TPED: Only outputting biallelic loci.");
 			continue;
 		}
 
@@ -314,9 +314,9 @@ void vcf_file::output_as_plink_tped(const string &output_file_prefix)
 
 	TPED.close();
 
-	printLOG("Writing PLINK TFAM file ... ");
+	LOG.printLOG("Writing PLINK TFAM file ... ");
 	ofstream TFAM(tfam_file.c_str());
-	if (!TFAM.is_open()) error("Could not open output file: " + tfam_file, 12);
+	if (!TFAM.is_open()) LOG.error("Could not open output file: " + tfam_file, 12);
 	for (unsigned int ui=0; ui<N_indv; ui++)
 	{
 		if (include_indv[ui] == false)
@@ -325,7 +325,7 @@ void vcf_file::output_as_plink_tped(const string &output_file_prefix)
 	}
 
 	TFAM.close();
-	printLOG("Done.\n");
+	LOG.printLOG("Done.\n");
 }
 
 /*
@@ -333,19 +333,19 @@ void vcf_file::output_as_plink_tped(const string &output_file_prefix)
 void vcf_file::output_as_012_matrix(const string &output_file_prefix)
 {
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to output as 0/1/2 matrix.");
+		LOG.error("Require Genotypes in VCF file in order to output as 0/1/2 matrix.");
 
-	printLOG("Writing 012 matrix file ... ");
+	LOG.printLOG("Writing 012 matrix file ... ");
 	string ped_file = output_file_prefix + ".012";
 	string map_file = output_file_prefix + ".012.pos";
 	string fam_file = output_file_prefix + ".012.indv";
 
 	ofstream PED(ped_file.c_str());
-	if (!PED.is_open()) error("Could not open output file: " + ped_file, 12);
+	if (!PED.is_open()) LOG.error("Could not open output file: " + ped_file, 12);
 	string allele1, allele2;
 
 	ofstream FAM(fam_file.c_str());
-	if (!FAM.is_open()) error("Could not open output file: " + fam_file, 12);
+	if (!FAM.is_open()) LOG.error("Could not open output file: " + fam_file, 12);
 
 	pair<int, int> genotype;
 	string vcf_line;
@@ -395,7 +395,7 @@ void vcf_file::output_as_012_matrix(const string &output_file_prefix)
 	PED.close();
 
 	ofstream MAP(map_file.c_str());
-	if (!MAP.is_open()) error("Could not open output file: " + map_file, 12);
+	if (!MAP.is_open()) LOG.error("Could not open output file: " + map_file, 12);
 	for (unsigned int s=0; s<N_entries; s++)
 	{
 		if (include_entry[s] == false)
@@ -411,7 +411,7 @@ void vcf_file::output_as_012_matrix(const string &output_file_prefix)
 	}
 
 	MAP.close();
-	printLOG("Done.\n");
+	LOG.printLOG("Done.\n");
 }
 */
 
@@ -419,15 +419,15 @@ void vcf_file::output_as_012_matrix(const string &output_file_prefix)
 {
 	// Output as PLINK formatted PED/MAP files.
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to output as 0/1/2 matrix.");
+		LOG.error("Require Genotypes in VCF file in order to output as 0/1/2 matrix.");
 
-	printLOG("Writing 012 matrix file ... ");
+	LOG.printLOG("Writing 012 matrix file ... ");
 	string ped_file = output_file_prefix + ".012";
 	string map_file = output_file_prefix + ".012.pos";
 	string fam_file = output_file_prefix + ".012.indv";
 
 	ofstream FAM(fam_file.c_str());
-	if (!FAM.is_open()) error("Could not open output file: " + fam_file, 12);
+	if (!FAM.is_open()) LOG.error("Could not open output file: " + fam_file, 12);
 
 	vector<ofstream *> tmp_files(N_indv);
 	vector<string> tmp_filenames(N_indv);
@@ -439,7 +439,7 @@ void vcf_file::output_as_012_matrix(const string &output_file_prefix)
 		string filename(tmpnam(NULL));
 		ofstream *tmp_file = new ofstream(filename.c_str());
 		if (!tmp_file->good())
-			error("\n\nCould not open temporary file.\n\n"
+			LOG.error("\n\nCould not open temporary file.\n\n"
 			"Most likely this is because the system is not allowing me to open enough temporary files.\n"
 			"Try using ulimit -n <int> to increase the number of allowed open files.\n", 12);
 		(*tmp_file) << ui;
@@ -466,7 +466,7 @@ void vcf_file::output_as_012_matrix(const string &output_file_prefix)
 
 		if (e.get_N_alleles() > 2)
 		{
-			one_off_warning("\t012: Only outputting biallelic loci.");
+			LOG.one_off_warning("\t012: Only outputting biallelic loci.");
 			continue;
 		}
 
@@ -503,7 +503,7 @@ void vcf_file::output_as_012_matrix(const string &output_file_prefix)
 	}
 
 	ofstream PED(ped_file.c_str());
-	if (!PED.is_open()) error("Could not open output file: " + ped_file, 12);
+	if (!PED.is_open()) LOG.error("Could not open output file: " + ped_file, 12);
 	string tmp_line;
 	for (unsigned int ui=0; ui<N_indv; ui++)
 	{
@@ -516,7 +516,7 @@ void vcf_file::output_as_012_matrix(const string &output_file_prefix)
 
 		ifstream read_file(tmp_filenames[ui].c_str());
 		if (!read_file.good())
-			error("\n\nCould not open temporary file.\n\n"
+			LOG.error("\n\nCould not open temporary file.\n\n"
 			"Most likely this is because the system is not allowing me to open enough temporary files.\n"
 			"Try using ulimit -n <int> to increase the number of allowed open files.\n", 12);
 		getline(read_file, tmp_line);
@@ -526,9 +526,9 @@ void vcf_file::output_as_012_matrix(const string &output_file_prefix)
 	}
 	PED.close();
 
-	printLOG("Writing 012 positions file ... ");
+	LOG.printLOG("Writing 012 positions file ... ");
 	ofstream MAP(map_file.c_str());
-	if (!MAP.is_open()) error("Could not open output file: " + map_file, 12);
+	if (!MAP.is_open()) LOG.error("Could not open output file: " + map_file, 12);
 	for (unsigned int s=0; s<N_entries; s++)
 	{
 		if (include_entry[s] == false)
@@ -544,32 +544,32 @@ void vcf_file::output_as_012_matrix(const string &output_file_prefix)
 	}
 
 	MAP.close();
-	printLOG("Done.\n");
+	LOG.printLOG("Done.\n");
 }
 
 // Output as IMPUTE format
 void vcf_file::output_as_IMPUTE(const string &output_file_prefix)
 {
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to output IMPUTE format.");
+		LOG.error("Require Genotypes in VCF file in order to output IMPUTE format.");
 
-	printLOG("Outputting in IMPUTE format (bi-allelic, completely phased SNPs only)\n");
+	LOG.printLOG("Outputting in IMPUTE format (bi-allelic, completely phased SNPs only)\n");
 	unsigned int s, ui;
 	string legend_file = output_file_prefix + ".impute.legend";
 	string haplotype_file = output_file_prefix + ".impute.hap";
 	string indv_file = output_file_prefix + ".impute.hap.indv";
 	ofstream legend(legend_file.c_str());
 	if (!legend.is_open())
-		error("Could not open IMPUTE Legend Output File: " + legend_file, 2);
+		LOG.error("Could not open IMPUTE Legend Output File: " + legend_file, 2);
 	legend << "ID pos allele0 allele1" << endl;
 
 	ofstream hap(haplotype_file.c_str());
 	if (!hap.is_open())
-		error("Could not open IMPUTE Haplotype Output File: " + haplotype_file, 2);
+		LOG.error("Could not open IMPUTE Haplotype Output File: " + haplotype_file, 2);
 
 	ofstream indv_out(indv_file.c_str());
 	if (!indv_out.is_open())
-		error("Could not open IMPUTE Individual Output File: " + indv_file, 2);
+		LOG.error("Could not open IMPUTE Individual Output File: " + indv_file, 2);
 
 	for (ui=0; ui<N_indv; ui++)
 	{
@@ -593,7 +593,7 @@ void vcf_file::output_as_IMPUTE(const string &output_file_prefix)
 
 		if (e.get_N_alleles() > 2)
 		{
-			one_off_warning("\tIMPUTE: Only outputting biallelic loci.");
+			LOG.one_off_warning("\tIMPUTE: Only outputting biallelic loci.");
 			continue;
 		}
 
@@ -662,7 +662,7 @@ void vcf_file::output_LDhat_locs_file(const string &output_file_prefix, const st
 	string locs_file = output_file_prefix + ".ldhat.locs";
 	ofstream locs(locs_file.c_str());
 	if (!locs.is_open())
-		error("Could not open LDhat locs Output File: " + locs_file, 2);
+		LOG.error("Could not open LDhat locs Output File: " + locs_file, 2);
 
 	int max_pos = -1;
 	unsigned int n_sites=0;
@@ -686,7 +686,7 @@ void vcf_file::output_LDhat_locs_file(const string &output_file_prefix, const st
 
 		e.get_CHROM(chrom);
 		if (chrom != chr)
-			error("Mismatching chromosome in LDhat loci", 13);
+			LOG.error("Mismatching chromosome in LDhat loci", 13);
 
 		max_pos = max(e.get_POS(), max_pos);
 		n_sites++;
@@ -707,7 +707,7 @@ void vcf_file::output_LDhat_locs_file(const string &output_file_prefix, const st
 
 		if (e.get_N_alleles() != 2)
 		{
-			one_off_warning("\tLDhat: Only outputting biallelic loci.");
+			LOG.one_off_warning("\tLDhat: Only outputting biallelic loci.");
 			continue;
 		}
 
@@ -721,11 +721,11 @@ void vcf_file::output_LDhat_locs_file(const string &output_file_prefix, const st
 void vcf_file::output_as_LDhat_phased(const string &output_file_prefix, const string &chr)
 {
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to output LDhat format.");
+		LOG.error("Require Genotypes in VCF file in order to output LDhat format.");
 
-	printLOG("Outputting in phased LDhat format\n");
+	LOG.printLOG("Outputting in phased LDhat format\n");
 	if (chr == "")
-		error("Require chromosome for LDhat output", 10);
+		LOG.error("Require chromosome for LDhat output", 10);
 
 	unsigned int n_sites;
 	output_LDhat_locs_file(output_file_prefix, chr, n_sites);
@@ -733,7 +733,7 @@ void vcf_file::output_as_LDhat_phased(const string &output_file_prefix, const st
 	string sites_file = output_file_prefix + ".ldhat.sites";
 	ofstream sites(sites_file.c_str());
 	if (!sites.is_open())
-		error("Could not open LDhat sites Output File: " + sites_file, 2);
+		LOG.error("Could not open LDhat sites Output File: " + sites_file, 2);
 
 	unsigned int n_indv = N_kept_individuals();
 	pair<int, int> alleles;
@@ -749,14 +749,14 @@ void vcf_file::output_as_LDhat_phased(const string &output_file_prefix, const st
 		string filename(tmpnam(NULL));
 		ofstream *tmp_file = new ofstream(filename.c_str());
 		if (!tmp_file->good())
-			error("Could not open temp file.\n", 12);
+			LOG.error("Could not open temp file #" + output_log::int2str(ui) + ".\n", 12);
 		tmp_files[2*ui] = tmp_file;
 		tmp_filenames[2*ui] = filename;
 
 		string filename2(tmpnam(NULL));
 		ofstream *tmp_file2 = new ofstream(filename2.c_str());
 		if (!tmp_file2->good())
-			error("\n\nCould not open temporary file.\n\n"
+			LOG.error("\n\nCould not open temporary file.\n\n"
 				"Most likely this is because the system is not allowing me to open enough temporary files.\n"
 				"Try using ulimit -n <int> to increase the number of allowed open files.\n", 12);
 		tmp_files[2*ui+1] = tmp_file2;
@@ -778,7 +778,7 @@ void vcf_file::output_as_LDhat_phased(const string &output_file_prefix, const st
 
 		if (e.get_N_alleles() != 2)
 		{
-			one_off_warning("\tLDhat: Only outputting biallelic loci.");
+			LOG.one_off_warning("\tLDhat: Only outputting biallelic loci.");
 			continue;
 		}
 
@@ -822,7 +822,7 @@ void vcf_file::output_as_LDhat_phased(const string &output_file_prefix, const st
 
 			ifstream read_file(tmp_filenames[2*ui+k].c_str());
 			if (!read_file.good())
-				error("\n\nCould not open temporary file.\n\n"
+				LOG.error("\n\nCould not open temporary file.\n\n"
 				"Most likely this is because the system is not allowing me to open enough temporary files.\n"
 				"Try using ulimit -n <int> to increase the number of allowed open files.\n", 12);
 			getline(read_file, tmp_line);
@@ -839,11 +839,11 @@ void vcf_file::output_as_LDhat_phased(const string &output_file_prefix, const st
 void vcf_file::output_as_LDhat_unphased(const string &output_file_prefix, const string &chr)
 {
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to output LDhat format.");
+		LOG.error("Require Genotypes in VCF file in order to output LDhat format.");
 
-	printLOG("Outputting in unphased LDhat format\n");
+	LOG.printLOG("Outputting in unphased LDhat format\n");
 	if (chr == "")
-		error("Require chromosome for LDhat output", 10);
+		LOG.error("Require chromosome for LDhat output", 10);
 
 	unsigned int n_sites;
 	output_LDhat_locs_file(output_file_prefix, chr, n_sites);
@@ -851,7 +851,7 @@ void vcf_file::output_as_LDhat_unphased(const string &output_file_prefix, const
 	string sites_file = output_file_prefix + ".ldhat.sites";
 	ofstream sites(sites_file.c_str());
 	if (!sites.is_open())
-		error("Could not open LDhat sites Output File: " + sites_file, 2);
+		LOG.error("Could not open LDhat sites Output File: " + sites_file, 2);
 
 	unsigned int n_indv = N_kept_individuals();
 	pair<int, int> alleles;
@@ -867,7 +867,7 @@ void vcf_file::output_as_LDhat_unphased(const string &output_file_prefix, const
 		string filename(tmpnam(NULL));
 		ofstream *tmp_file = new ofstream(filename.c_str());
 		if (!tmp_file->good())
-			error("\n\nCould not open temporary file.\n\n"
+			LOG.error("\n\nCould not open temporary file.\n\n"
 					"Most likely this is because the system is not allowing me to open enough temporary files.\n"
 					"Try using ulimit -n <int> to increase the number of allowed open files.\n", 12);
 		tmp_files[ui] = tmp_file;
@@ -888,7 +888,7 @@ void vcf_file::output_as_LDhat_unphased(const string &output_file_prefix, const
 
 		if (e.get_N_alleles() != 2)
 		{
-			one_off_warning("\tLDhat: Only outputting biallelic loci.");
+			LOG.one_off_warning("\tLDhat: Only outputting biallelic loci.");
 			continue;
 		}
 
@@ -932,6 +932,7 @@ void vcf_file::output_as_LDhat_unphased(const string &output_file_prefix, const
 					break;
 				default:
 					(*tmp_file) << '?';
+					break;
 				}
 			}
 		}
@@ -949,7 +950,7 @@ void vcf_file::output_as_LDhat_unphased(const string &output_file_prefix, const
 
 		ifstream read_file(tmp_filenames[ui].c_str());
 		if (!read_file.good())
-			error("\n\nCould not open temporary file.\n\n"
+			LOG.error("\n\nCould not open temporary file.\n\n"
 				"Most likely this is because the system is not allowing me to open enough temporary files.\n"
 				"Try using ulimit -n <int> to increase the number of allowed open files.\n", 12);
 		getline(read_file, tmp_line);
@@ -968,11 +969,11 @@ void vcf_file::output_INFO_for_each_site(const string &output_file_prefix, const
 	if (INFO_to_extract.size() == 0)
 		return;
 
-	printLOG("Outputting INFO for each site\n");
+	LOG.printLOG("Outputting INFO for each site\n");
 	string output = output_file_prefix + ".INFO";
 	ofstream out(output.c_str());
 	if (!out.is_open())
-		error("Could not open INFO Output File: " + output, 3);
+		LOG.error("Could not open INFO Output File: " + output, 3);
 
 	out << "CHROM\tPOS\tREF\tALT";
 	for (unsigned int ui=0; ui<INFO_to_extract.size(); ui++)
@@ -1010,13 +1011,13 @@ void vcf_file::output_FORMAT_information(const string &output_file_prefix, const
 		return;
 
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to output FORMAT information.");
+		LOG.error("Require Genotypes in VCF file in order to output FORMAT information.");
 
-	printLOG("Outputting FORMAT information for " + FORMAT_id + "\n");
+	LOG.printLOG("Outputting FORMAT information for " + FORMAT_id + "\n");
 	string output = output_file_prefix + "." + FORMAT_id + ".FORMAT";
 	ofstream out(output.c_str());
 	if (!out.is_open())
-		error("Could not open FORMAT Output File: " + output, 7);
+		LOG.error("Could not open FORMAT Output File: " + output, 7);
 
 	out << "CHROM\tPOS";
 	for (unsigned int ui=0; ui<N_indv; ui++)
@@ -1061,14 +1062,14 @@ void vcf_file::output_FORMAT_information(const string &output_file_prefix, const
 void vcf_file::output_BEAGLE_genotype_likelihoods(const string &output_file_prefix)
 {
 	if (has_genotypes == false)
-		error("Require Genotypes in VCF file in order to output BEAGLE genotype likelihoods.");
+		LOG.error("Require Genotypes in VCF file in order to output BEAGLE genotype likelihoods.");
 
-	printLOG("Outputting in BEAGLE Genotype Likelihood format (bi-allelic SNPs with GL tags only)\n");
+	LOG.printLOG("Outputting in BEAGLE Genotype Likelihood format (bi-allelic SNPs with GL tags only)\n");
 
 	string output = output_file_prefix + ".BEAGLE.GL";
 	ofstream out(output.c_str());
 	if (!out.is_open())
-		error("Could not open BEAGLE GL Output File: " + output, 3);
+		LOG.error("Could not open BEAGLE GL Output File: " + output, 3);
 	out << "marker\talleleA\talleleB";
 	for (unsigned int ui=0; ui<N_indv; ui++)
 	{
@@ -1094,7 +1095,7 @@ void vcf_file::output_BEAGLE_genotype_likelihoods(const string &output_file_pref
 
 		if (e.get_N_alleles() != 2)
 		{
-			one_off_warning("\tBEAGLE: Only outputting biallelic loci.");
+			LOG.one_off_warning("\tBEAGLE: Only outputting biallelic loci.");
 			continue;
 		}
 
@@ -1133,6 +1134,6 @@ void vcf_file::output_BEAGLE_genotype_likelihoods(const string &output_file_pref
 	}
 
 	if (found_GL == false)
-		error("Require GL FORMAT tags in VCF file to output BEAGLE input.");
+		LOG.error("Require GL FORMAT tags in VCF file to output BEAGLE input.");
 }
 
